@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: pscoupe.c,v 1.33 2007/09/26 16:22:47 guru Exp $
+ *    $Id: pscoupe.c,v 1.49 2010/07/05 20:38:22 jluis Exp $
  *
- *    Copyright (c) 1996-2007 by G. Patau
+ *    Copyright (c) 1996-2010 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
@@ -41,29 +41,29 @@ PostScript code is written to stdout.
 int main (int argc, char **argv)
 {
 
-    int     i, j, symbol = 0, n, ix = 0, iy = 1, n_files = 0, fno;
-    int     n_args;
-    int     n_rec = 0;
+    GMT_LONG     i, j, symbol = 0, n, ix = 0, iy = 1, n_files = 0, fno;
+    GMT_LONG     n_args;
+    GMT_LONG     n_rec = 0;
 
-    BOOLEAN    outline = FALSE, p_outline = FALSE, t_outline = FALSE;
-    BOOLEAN    error = FALSE, nofile = TRUE, polygon = FALSE;
-    BOOLEAN    done, get_rgb = FALSE, no_size_needed, greenwich;
-    BOOLEAN    read_size = FALSE, read_proj = FALSE;
-    BOOLEAN    read_cmt = FALSE, read_aki = FALSE, read_planes = FALSE;
-    BOOLEAN    read_tensor = FALSE, read_axis = FALSE, read_point = FALSE;
-    BOOLEAN    plot_dc = FALSE, plot_tensor = FALSE, plot_axis = FALSE;
-    BOOLEAN    plot_zerotrace = FALSE, tr_zerotrace = FALSE;
-    BOOLEAN    transparence = FALSE, one_size = FALSE, no_label = FALSE;
-    BOOLEAN    frame_coupe = FALSE;
-    BOOLEAN    old_GMT_world_map, skip_if_outside = TRUE;
-    BOOLEAN    transparence_old = FALSE, not_defined = FALSE;
+    GMT_LONG    outline = FALSE, p_outline = FALSE, t_outline = FALSE;
+    GMT_LONG    error = FALSE, nofile = TRUE, polygon = FALSE;
+    GMT_LONG    done, get_rgb = FALSE, no_size_needed, greenwich;
+    GMT_LONG    read_size = FALSE, read_proj = FALSE;
+    GMT_LONG    read_cmt = FALSE, read_aki = FALSE, read_planes = FALSE;
+    GMT_LONG    read_tensor = FALSE, read_axis = FALSE, read_point = FALSE;
+    GMT_LONG    plot_dc = FALSE, plot_tensor = FALSE, plot_axis = FALSE;
+    GMT_LONG    plot_zerotrace = FALSE, tr_zerotrace = FALSE;
+    GMT_LONG    transparence = FALSE, one_size = FALSE, no_label = FALSE;
+    GMT_LONG    frame_coupe = FALSE;
+    GMT_LONG    old_GMT_world_map, skip_if_outside = TRUE;
+    GMT_LONG    transparence_old = FALSE, not_defined = FALSE;
     
     double xy[2], west = 0.0, east = 0.0, south = 0.0, north = 0.0;
     double plot_x, plot_y, scale = 0.0;
 
     char event_title[BUFSIZ], txt_a[GMT_TEXT_LEN];
 
-    char line[BUFSIZ], symbol_type, col[15][GMT_TEXT_LEN], *cpt = CNULL;
+    char line[BUFSIZ], symbol_type, col[15][GMT_TEXT_LEN], *cpt = CNULL, *not_used = NULL;
     char newfile[GMT_LONG_TEXT], extracted_file[GMT_LONG_TEXT];
     
     FILE *fp = NULL;
@@ -80,13 +80,13 @@ int main (int argc, char **argv)
     struct M_TENSOR mt, mtr;
     struct AXIS T, N, P, Tr, Nr, Pr;
 
-    int n_plane = 0, n_plane_old = 0;
-    int default_justify = 2;
-    int justify = default_justify, form = 0;
+    GMT_LONG n_plane = 0, n_plane_old = 0;
+    GMT_LONG default_justify = 2;
+    GMT_LONG justify = default_justify, form = 0;
 
     double default_fontsize = 9.0;
     double fontsize = default_fontsize;
-    double default_offset = gmtdefs.measure_unit == 0 ? 0.1 : 0.04;
+    double default_offset = (gmtdefs.measure_unit == GMT_CM ? 0.1 : 0.04);
     double offset = default_offset, angle = 0.0;
     double size = 0.0;
     double tmp1, tmp2, tmp3, tmp4, tmp5;
@@ -95,14 +95,14 @@ int main (int argc, char **argv)
     double fault, depth, dmin, dmax;
     double p_length, p_width, lon1, lat1, lon2, lat2;
     char project_type;
-    int syscoord, fuseau = 0;
+    GMT_LONG syscoord, fuseau = 0;
 
     double P_x, P_y, T_x, T_y, a_size = GMT_d_NaN;
     char P_sym_type = 0, T_sym_type = 0;
-    int P_sym = 0, T_sym = 0;
-	void distaz (double lat1,double lon1,double lat2,double lon2,double *distrad,double *distdeg,double *distkm,double *az12rad,double *az12deg,double *az21rad,double *az21deg,int syscoord);
+    GMT_LONG P_sym = 0, T_sym = 0;
+	void distaz (double lat1,double lon1,double lat2,double lon2,double *distrad,double *distdeg,double *distkm,double *az12rad,double *az12deg,double *az21rad,double *az21deg,GMT_LONG syscoord);
 
-    argc = GMT_begin (argc, argv);
+    argc = (int)GMT_begin (argc, argv);
     
     GMT_init_pen (&pen, GMT_PENWIDTH);
     GMT_init_fill (&fill, 0, 0, 0);
@@ -221,9 +221,9 @@ int main (int argc, char **argv)
                     if(strstr(argv[i], "/\0") != NULL) {
                         sscanf(strstr(argv[i], "/\0"), "/%lf/%lf",
                            &fontsize, &offset);
-                        if (fontsize == 0.0) fontsize = default_fontsize;
+                        if (GMT_IS_ZERO (fontsize)) fontsize = default_fontsize;
                         if (fontsize < 0.0) no_label = TRUE;
-                        if (offset == 0.0) offset = default_offset;
+                        if (GMT_IS_ZERO (offset)) offset = default_offset;
                         if (argv[i][strlen(argv[i]) - 1] == 'u') justify = 10;
                     }
 
@@ -281,9 +281,9 @@ int main (int argc, char **argv)
                     if(strstr(argv[i], "/\0") != NULL) {
                         sscanf(strstr(argv[i], "/\0"), "/%lf/%lf",
                            &fontsize, &offset);
-                        if (fontsize == 0.0) fontsize = default_fontsize;
+                        if (GMT_IS_ZERO (fontsize)) fontsize = default_fontsize;
                         if (fontsize < 0.0) no_label = TRUE;
-                        if (offset == 0.0) offset = default_offset;
+                        if (GMT_IS_ZERO (offset)) offset = default_offset;
                         if (argv[i][strlen(argv[i]) - 1] == 'u') justify = 10;
                     }
 
@@ -318,7 +318,7 @@ int main (int argc, char **argv)
                                 argv[0], symbol_type);
                         break;
                     }
-                    if (scale == 0.0) {
+                    if (GMT_IS_ZERO (scale)) {
                         read_size = TRUE;
                     }
                     size = scale;
@@ -326,7 +326,7 @@ int main (int argc, char **argv)
                     break;
                 case 'T':
                     transparence = TRUE;
-                    sscanf (&argv[i][2], "%d",&n_plane);
+                    sscanf (&argv[i][2], "%" GMT_LL "d",&n_plane);
                     if(strlen(argv[i]) > 3) { /* Set transparent attributes */
                         if (argv[i][2] && GMT_getpen (&argv[i][2], &tr_pen)) {
                             GMT_pen_syntax ('T', " ");
@@ -513,7 +513,7 @@ int main (int argc, char **argv)
         
         if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
         
-        fprintf (stderr, "    <infiles> is one or more files.  If no, read standard input\n");
+        fprintf (stderr, "    <infiles> is one or more files. If no files are given, read standard input\n");
         fprintf (stderr, "        -A Specify cross-section parameters. Choose between\n");
         fprintf (stderr, "           -Aa<lon1/lat1/lon2/lat2/dip/p_width/dmin/dmax>[f]\n");
         fprintf (stderr, "           -Ab<lon1/lat1/strike/p_length/dip/p_width/dmin/dmax>[f]\n");
@@ -535,27 +535,27 @@ int main (int argc, char **argv)
         GMT_explain_option ('P');
         fprintf (stderr, "        -S Select format type and symbol size (in measure_unit).\n");
         fprintf (stderr, "           Choose format between\n");
-        fprintf (stderr, "         (c) Focal mechanisms in CMT convention\n");
+        fprintf (stderr, "         (c) Focal mechanisms in Harvard CMT convention\n");
         fprintf (stderr, "             X, Y, depth, strike1, dip1, rake1, strike2, dip2, rake2, moment, event_title\n");
         fprintf (stderr, "             with moment in 2 columns : mantiss and exponent corresponding to seismic moment in dynes-cm\n");
-        fprintf (stderr, "         (a) Focal mechanism in AKI & RICHARD's convention:\n");
+        fprintf (stderr, "         (a) Focal mechanism in Aki & Richard's convention:\n");
         fprintf (stderr, "             X, Y, depth, strike, dip, rake, mag, event_title\n");
         fprintf (stderr, "         (p) Focal mechanism defined with\n");
         fprintf (stderr, "             X, Y, depth, strike1, dip1, strike2, fault, mag, event_title\n");
         fprintf (stderr, "             fault = -1/+1 for a normal/inverse fault\n");
-        fprintf (stderr, "         (m) Moment tensor (Harvard CMT)\n");
+        fprintf (stderr, "         (m) Sesmic moment tensor (Harvard CMT, with zero trace)\n");
         fprintf (stderr, "             X, Y, depth, mrr, mtt, mff, mrt, mrf, mtf, exp, event_title\n");
-        fprintf (stderr, "         (z) Zero trace moment tensor\n");
-        fprintf (stderr, "             X, Y, depth, mrr, mtt, mff, mrt, mrf, mtf, exp, newX, newY, event_title\n");
-        fprintf (stderr, "         (d) Best double couple defined from moment tensor\n");
+        fprintf (stderr, "         (z) Anisotropic part of seismic moment tensor (Harvard CMT, with zero trace)\n");
         fprintf (stderr, "             X, Y, depth, mrr, mtt, mff, mrt, mrf, mtf, exp, event_title\n");
-        fprintf (stderr, "         (x) Axis (Harvard CMT)\n");
+        fprintf (stderr, "         (d) Best double couple defined from seismic moment tensor (Harvard CMT, with zero trace)\n");
+        fprintf (stderr, "             X, Y, depth, mrr, mtt, mff, mrt, mrf, mtf, exp, event_title\n");
+        fprintf (stderr, "         (x) Principal axis\n");
         fprintf (stderr, "             X,Y,depth,T_value,T_azimuth,T_plunge,N_value,N_azimuth,N_plunge,\n");
         fprintf (stderr, "             P_value,P_azimuth,P_plunge,exp,event_title\n");
-        fprintf (stderr, "         (t) Zero trace moment tensor defined from axis\n");
+        fprintf (stderr, "         (t) Zero trace moment tensor defined from principal axis\n");
         fprintf (stderr, "             X, Y, depth, T_value, T_azim, T_plunge, N_value, N_azim, N_plunge\n");
         fprintf (stderr, "             P_value, P_azim, P_plunge, exp, newX, newY, event_title\n");
-        fprintf (stderr, "         (y) Best double couple defined main axis (Harvard CMT)\n");
+        fprintf (stderr, "         (y) Best double couple defined from principal axis\n");
         fprintf (stderr, "             X,Y,depth,T_value,T_azimuth,T_plunge,N_value,N_azimuth,N_plunge,\n");
         fprintf (stderr, "             P_value,P_azimuth,P_plunge,exp,event_title\n");
         fprintf (stderr, "         Optionally add /fontsize[/offset][u]\n");
@@ -601,7 +601,7 @@ int main (int argc, char **argv)
         east = p_length;
         south = dmin;
         north = dmax;
-        if(PREF.dip == 0.) PREF.dip = 1.;
+        if (GMT_IS_ZERO (PREF.dip)) PREF.dip = 1.0;
     }
 
     greenwich = (project_info.w < 0.0 || project_info.e <= 0.0);
@@ -639,7 +639,7 @@ int main (int argc, char **argv)
             ps_comment (line);
         }
         if (GMT_io.io_header[GMT_IN]) 
-            for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
+            for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (line, BUFSIZ, fp);
         
 
         while (GMT_fgets (line, BUFSIZ, fp)) {
@@ -697,7 +697,7 @@ int main (int argc, char **argv)
 
             if (skip_if_outside) {
                 GMT_map_outside (xy[0], xy[1]);
-                if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
+                if (GMT_abs (GMT_x_status_new) > 1 || GMT_abs (GMT_y_status_new) > 1) continue;
             }
 
             if (get_rgb) {
@@ -819,7 +819,7 @@ NP2.str, meca.NP2.dip, fault);
                 P.e = atoi(col[12]);
 
 /*
-F. A. Dahlen and Jeoren Trom, Theoretical Seismology, Princeton, 1998, p.167.
+F. A. Dahlen and Jeroen Tromp, Theoretical Seismology, Princeton, 1998, p.167.
 Definition of scalar moment.
 */
                 meca.moment.exponent = T.e;
@@ -857,17 +857,17 @@ Definition of scalar moment.
 
                 moment.exponent = mt.expo;
 /*
-F. A. Dahlen and Jeoren Trom, Theoretical Seismology, Princeton, 1998, p.167.
+F. A. Dahlen and Jeroen Tromp, Theoretical Seismology, Princeton, 1998, p.167.
 Definition of scalar moment.
 */
                 moment.mant = sqrt(squared(mt.f[0]) + squared(mt.f[1]) + squared(mt.f[2]) + 2.*(squared(mt.f[3]) + squared(mt.f[4]) + squared(mt.f[5]))) / M_SQRT2;
                 meca.magms = 0.;
 
 /* normalization by M0 */
-                for(i=0;i<=5;i++) mt.f[i] /= meca.moment.mant;
+                for(i=0;i<=5;i++) mt.f[i] /= moment.mant;
 
                 rot_tensor(mt, PREF, &mtr);
-                momten2axe(mtr, &T, &N, &P);
+                GMT_momten2axe(mtr, &T, &N, &P);
 
                 if(plot_dc || transparence) {
                     axe2dc(T, P, &NP1, &NP2);
@@ -890,7 +890,7 @@ Definition of scalar moment.
 
                 fprintf(pextract, "%s", line);
                 if(read_axis) {
-                    fprintf(pnew, "%f %f %f %f %f %f %f %f %f %f %f %f %d 0 0 %s\n", 
+                    fprintf(pnew, "%f %f %f %f %f %f %f %f %f %f %f %f %ld 0 0 %s\n", 
                         xy[0], xy[1], depth, Tr.val, Tr.str, Tr.dip, Nr.val, Nr.str, Nr.dip, 
                         Pr.val, Pr.str, Pr.dip, moment.exponent, event_title);
                     T = Tr;
@@ -898,13 +898,13 @@ Definition of scalar moment.
                     P = Pr;
                 }
                 else if(read_tensor) {
-                    fprintf(pnew, "%f %f %f %f %f %f %f %f %f %d 0 0 %s\n",
+                    fprintf(pnew, "%f %f %f %f %f %f %f %f %f %ld 0 0 %s\n",
                         xy[0], xy[1], depth, mtr.f[0], mtr.f[1], mtr.f[2], mtr.f[3], mtr.f[4], mtr.f[5],
                         moment.exponent, event_title);
                     mt = mtr;
                 }
                 else {
-                    fprintf(pnew, "%f %f %f %f %f %f %f %f %f %f %d 0 0 %s\n",
+                    fprintf(pnew, "%f %f %f %f %f %f %f %f %f %f %ld 0 0 %s\n",
                         xy[0], xy[1], depth, mecar.NP1.str, mecar.NP1.dip, mecar.NP1.rake, 
                         mecar.NP2.str, mecar.NP2.dip, mecar.NP2.rake,
                         moment.mant, moment.exponent, event_title);
@@ -1018,7 +1018,7 @@ Definition of scalar moment.
     }
     
     if (gmtdefs.verbose) 
-        fprintf (stderr, "pscoupe: Number of records read: %i\n", n_rec);
+        fprintf (stderr, "pscoupe: Number of records read: %li\n", n_rec);
 
 
     if (skip_if_outside) GMT_map_clip_off ();
