@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: pspolar.c,v 1.32 2009/07/11 03:16:31 guru Exp $ 
+ *    $Id: pspolar.c,v 1.38 2010/03/24 23:06:06 jluis Exp $ 
  *
- *    Copyright (c) 1996-2009 by G. Patau
+ *    Copyright (c) 1996-2010 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
@@ -42,16 +42,16 @@ int main (int argc, char **argv)
     GMT_LONG     n_args;
     GMT_LONG     form_s = 0, justify_s = 5;
     
-    BOOLEAN error = FALSE, nofile = TRUE;
-    BOOLEAN done, greenwich, label_s = FALSE;
-    BOOLEAN change_position = FALSE;
-    BOOLEAN get_position = FALSE, get_size = FALSE, get_symbol = FALSE;
-    BOOLEAN outline_E = FALSE, outline_G = FALSE, outline_F = FALSE;
-    BOOLEAN old_GMT_world_map, skip_if_outside = TRUE;
-    BOOLEAN plot_polS = FALSE, vecS = FALSE, scolor = FALSE, outline_s = FALSE;
-    BOOLEAN def_cpen = FALSE, def_fpen = FALSE, def_tpen = FALSE;
-    BOOLEAN def_gpen = FALSE, def_epen = FALSE, def_spen = FALSE;
-    BOOLEAN hypo = FALSE;
+    GMT_LONG error = FALSE, nofile = TRUE;
+    GMT_LONG done, greenwich, label_s = FALSE;
+    GMT_LONG change_position = FALSE;
+    GMT_LONG get_position = FALSE, get_size = FALSE, get_symbol = FALSE;
+    GMT_LONG outline_E = FALSE, outline_G = FALSE, outline_F = FALSE;
+    GMT_LONG old_GMT_world_map, skip_if_outside = TRUE;
+    GMT_LONG plot_polS = FALSE, vecS = FALSE, scolor = FALSE, outline_s = FALSE;
+    GMT_LONG def_cpen = FALSE, def_fpen = FALSE, def_tpen = FALSE;
+    GMT_LONG def_gpen = FALSE, def_epen = FALSE, def_spen = FALSE;
+    GMT_LONG hypo = FALSE;
     
     double west = 0.0, east = 0.0, south = 0.0, north = 0.0;
     double plot_x, plot_y, symbol_size = 0.0, symbol_size2;
@@ -75,7 +75,7 @@ int main (int argc, char **argv)
     struct GMT_FILL fill, ffill, gfill, efill, sfill;
     struct GMT_FILL black, nofill;
     
-    argc = GMT_begin (argc, argv);
+    argc = (int)GMT_begin (argc, argv);
     
     GMT_init_pen (&pen, GMT_PENWIDTH);
     GMT_init_fill (&nofill, -1, -1, -1); 
@@ -250,7 +250,7 @@ int main (int argc, char **argv)
                 case 'T':       /* Information about label printing */
                         label_s = TRUE;
                         if (strlen(argv[i]) > 2) {
-                             sscanf (&argv[i][2], "%lf/%ld/%ld/%lf/", &angle_s,
+                             sscanf (&argv[i][2], "%lf/%" GMT_LL "d/%" GMT_LL "d/%lf/", &angle_s,
                                      &form_s, &justify_s, &fontsize_s);
                         }
                         break;
@@ -316,7 +316,7 @@ int main (int argc, char **argv)
         fprintf (stderr, "        -E Specify color symbol for station in extensive part.\n");
         fprintf (stderr, "           Fill can be either <r/g/b> (each 0-255) for color \n");
         fprintf (stderr, "           or <gray> (0-255) for gray-shade [0].\n");
-        fprintf (stderr, "           Default is light grey.\n");
+        fprintf (stderr, "           Default is light gray.\n");
         fprintf (stderr, "        -e Outline of station symbol in extensive part.\n");
         fprintf (stderr, "           Default is current pen.\n");
         fprintf (stderr, "        -F Specify background color of beach ball. It can be\n");
@@ -420,7 +420,7 @@ int main (int argc, char **argv)
         }
         if (skip_if_outside) {
             GMT_map_outside (lon, lat);
-            if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
+            if (GMT_abs (GMT_x_status_new) > 1 || GMT_abs (GMT_y_status_new) > 1) continue;
         }
 
         GMT_setpen (&fpen);
