@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: psvelo.c,v 1.33 2009/01/18 00:28:57 jluis Exp $
+ *    $Id: psvelo.c,v 1.40 2010/03/24 23:06:06 jluis Exp $
  *
- *    Copyright (c) 1996-2009 by G. Patau
+ *    Copyright (c) 1996-2010 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
@@ -47,21 +47,21 @@ PostScript code is written to stdout.
 
 int main (int argc, char **argv)
 {
-	int 	i, symbol = 0, n, ix = 0, iy = 1, n_files = 0, fno;
-	int	n_args;
+	GMT_LONG 	i, symbol = 0, n, ix = 0, iy = 1, n_files = 0, fno;
+	GMT_LONG	n_args;
 	GMT_LONG     n_rec = 0;
 
-	BOOLEAN	outline = FALSE;
-	BOOLEAN	error = FALSE, nofile = TRUE, polygon = FALSE;
-	BOOLEAN shade_uncert = FALSE;
-	BOOLEAN rescale_sigma = FALSE;
-	BOOLEAN done, no_size_needed, greenwich;
-	BOOLEAN read_ellipse = FALSE, read_rotated_ellipse = FALSE;
-	BOOLEAN des_ellipse = TRUE, des_arrow = TRUE;
-	BOOLEAN read_anisotropy = FALSE;
-	BOOLEAN read_wedge = FALSE;
-	BOOLEAN read_cross = FALSE;
-	BOOLEAN old_GMT_world_map, skip_if_outside = TRUE;
+	GMT_LONG	outline = FALSE;
+	GMT_LONG	error = FALSE, nofile = TRUE, polygon = FALSE;
+	GMT_LONG shade_uncert = FALSE;
+	GMT_LONG rescale_sigma = FALSE;
+	GMT_LONG done, no_size_needed, greenwich;
+	GMT_LONG read_ellipse = FALSE, read_rotated_ellipse = FALSE;
+	GMT_LONG des_ellipse = TRUE, des_arrow = TRUE;
+	GMT_LONG read_anisotropy = FALSE;
+	GMT_LONG read_wedge = FALSE;
+	GMT_LONG read_cross = FALSE;
+	GMT_LONG old_GMT_world_map, skip_if_outside = TRUE;
 
 	double xy[2], west = 0.0, east = 0.0, south = 0.0, north = 0.0;
 	double plot_x, plot_y, scale = 0.0;
@@ -75,7 +75,7 @@ int main (int argc, char **argv)
 	double t11 = 1.0, t12 = 0.0, t21 = 0.0, t22 = 1.0;
 	double hl,hw,vw, fontsize = 0.0;
 
-	char *station_name;
+	char *station_name, *not_used = NULL;
 	char txt_a[GMT_TEXT_LEN], txt_b[GMT_TEXT_LEN], txt_c[GMT_TEXT_LEN];
 	char line[BUFSIZ], symbol_type, col[12][GMT_TEXT_LEN];
 
@@ -85,9 +85,9 @@ int main (int argc, char **argv)
 	struct GMT_PEN pen;
 	struct GMT_FILL fill, efill; /* efill is for uncertainty wedge */
 
-	int justify;
+	GMT_LONG justify;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	GMT_init_pen (&pen, GMT_PENWIDTH);
 	GMT_init_fill (&fill, 0, 0, 0);
@@ -308,7 +308,7 @@ int main (int argc, char **argv)
 			sprintf (line, "File: %s", argv[fno]);
 			ps_comment (line);
 		}
-		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (line, 512, fp);
+		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (line, 512, fp);
 
 		if (gmtdefs.verbose && (read_ellipse || read_rotated_ellipse))	 
 		  fprintf (stderr, "psvelo: 2-D confidence interval and scaling factor %f %f\n",confidence, conrad);
@@ -347,7 +347,7 @@ int main (int argc, char **argv)
                                         ellipse_convert(sigma_x, sigma_y, corr_xy, conrad, &small_axis, &great_axis, &direction);
 
                                     /* convert to degrees */
-                                       direction = direction / D2R;
+                                       direction = direction * R2D;
                                     }
                         }
                         else if(read_rotated_ellipse) {
@@ -377,7 +377,7 @@ int main (int argc, char **argv)
                         }
 
 			GMT_map_outside (xy[0], xy[1]);
-			if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
+			if (GMT_abs (GMT_x_status_new) > 1 || GMT_abs (GMT_y_status_new) > 1) continue;
 
 			GMT_geo_to_xy (xy[0], xy[1], &plot_x, &plot_y);
 
