@@ -1,4 +1,4 @@
-/*	$Id: utilmeca.c,v 1.23 2010/01/05 01:15:48 guru Exp $
+/*	$Id: utilmeca.c,v 1.24 2010/03/22 18:55:46 guru Exp $
  *    Copyright (c) 1996-2010 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
@@ -60,7 +60,7 @@ void get_trans (double slon,double slat,double *t11,double *t12,double *t21,doub
 }
 
 /***********************************************************************************************************/
-double  ps_mechanism(double x0, double y0, st_me meca, double size, int rgb[3], int ergb[3], BOOLEAN outline)
+double  ps_mechanism(double x0, double y0, st_me meca, double size, int rgb[3], int ergb[3], GMT_LONG outline)
 
 /* Genevieve Patau */
 
