@@ -1,5 +1,5 @@
-/*	$Id: utilvelo.c,v 1.11 2009/05/13 21:06:43 guru Exp $
- *    Copyright (c) 1996-2009 by G. Patau
+/*	$Id: utilvelo.c,v 1.13 2010/03/22 18:55:46 guru Exp $
+ *    Copyright (c) 1996-2010 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  */
@@ -204,7 +204,7 @@ void ellipse_convert (double sigx,double sigy,double rho,double conrad,double *e
 }
 
 /********************************************************************/
-void paint_ellipse (double x0, double y0, double angle, double major, double minor, double scale, double t11,double t12,double t21,double t22, GMT_LONG polygon, int rgb[3], BOOLEAN outline)
+void paint_ellipse (double x0, double y0, double angle, double major, double minor, double scale, double t11,double t12,double t21,double t22, GMT_LONG polygon, int rgb[3], GMT_LONG outline)
 
 /* Make an ellipse at center x0,y0  */
 
