@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77list.c,v 1.115 2010/04/03 02:25:05 guru Exp $
+ *	$Id: mgd77list.c,v 1.117 2010/07/25 10:52:22 guru Exp $
  *
  *    Copyright (c) 2004-2010 by P. Wessel
  *    See README file for copying and redistribution conditions.
@@ -241,13 +241,13 @@ int main (int argc, char **argv)
 				if (!strcmp (f_setting, "all")) strcpy (f_setting, MGD77_ALL);
 				if (!strcmp (f_setting, "all+")) {
 					strcpy (f_setting, MGD77_ALL);
-					strcpy (f_setting, ",");
+					strcat (f_setting, ",");
 					strcat (f_setting, MGD77_AUX);
 				}
 				if (!strcmp (f_setting, "mgd77")) strcpy (f_setting, MGD77_GEO);
 				if (!strcmp (f_setting, "mgd77+")) {
 					strcpy (f_setting, MGD77_GEO);
-					strcpy (f_setting, ",");
+					strcat (f_setting, ",");
 					strcat (f_setting, MGD77_AUX);
 				}
 				break;
@@ -419,7 +419,7 @@ int main (int argc, char **argv)
 	if (GMT_give_synopsis_and_exit || argc == 1) {	/* Display usage */
 		fprintf(stderr,"mgd77list %s - Extract data from MGD77 files\n\n", MGD77_VERSION);
 		fprintf (stderr,"usage: mgd77list <cruise(s)> -F<dataflags>[,<tests>] [-A[+]c|d|f|m|t[code]] [-Cf|g|e] [-Da<startdate>] [-Db<stopdate>] [-E]\n");
-		fprintf (stderr, "\t[-H] [-I<code>] [-L[<corrtable.txt>]] [-N[s|p][e|k|n|m]]] [-Qa|v<min>/<max>] [%s]\n", GMT_Rgeo_OPT);
+		fprintf (stderr, "\t[-Ga<startrec>] [-Gb<stoprec>] [-H] [-I<code>] [-L[<corrtable.txt>]] [-N[s|p][e|k|n|m]]] [-Qa|v<min>/<max>] [%s]\n", GMT_Rgeo_OPT);
 		fprintf (stderr, "\t[-Sa<startdist>[unit]] [-Sb<stopdist>[unit]] [-T[m|e]] [-V] [-W<Weight>] [-Z[+|-] [%s] [%s]\n\n", GMT_bo_OPT, GMT_mo_OPT);
          
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
@@ -538,6 +538,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t  If A|B is used instead or a|b then records with no time are excluded from output\n");
 		fprintf (stderr, "\t-E Only records that exactly matches the requested geophysical information in -F will be used.\n");
 		fprintf (stderr, "\t   [Default will output all record that matches at least one column]\n");
+		fprintf (stderr, "\t-Ga<rec> lists from given record [Start of cruise]\n");
+		fprintf (stderr, "\t  b<rec> lists up to given record [End of cruise]\n");
 		fprintf (stderr, "\t-H Write one header record with column names\n");
 		fprintf (stderr, "\t-I Ignore certain data file formats from consideration. Append combination of act to ignore\n");
 		fprintf (stderr, "\t   (a) MGD77 ASCII, (c) MGD77+ netCDF, or (t) plain table files. [Default ignores none]\n");
