@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77magref.c,v 1.26 2010/06/25 20:33:49 guru Exp $
+ *	$Id: mgd77magref.c,v 1.27 2010/07/25 18:59:59 jluis Exp $
  *
  *    Copyright (c) 2009-2010 by J. Luis and P. Wessel
  *    See README file for copying and redistribution conditions.
@@ -91,10 +91,10 @@ int main (int argc, char **argv) {
 					Ctrl->M.path = strdup (&argv[i][2]);
 					break;
 				case 'D':
-					this_i = i;
+					this_i = 2;
 					if (argv[i][2] == '-') this_i++;
-					if ((argv[this_i][2] > 47) && (argv[this_i][2] < 58)) {	/* arg is numeric -> Dst Index */
-						Ctrl->D.dst[0] = atof(&argv[this_i][2]);
+					if ((argv[i][this_i] > 47) && (argv[i][this_i] < 58)) {	/* arg is numeric -> Dst Index */
+						Ctrl->D.dst[0] = atof(&argv[i][2]);
 						Ctrl->D.index = FALSE; 
 					}
 					else {
