@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77manage.c,v 1.130 2009/07/11 03:16:31 guru Exp $
+ *	$Id: mgd77manage.c,v 1.142 2010/07/26 20:35:42 guru Exp $
  *
- *    Copyright (c) 2005-2009 by P. Wessel
+ *    Copyright (c) 2005-2010 by P. Wessel
  * mgd77manage is used to (1) remove data columns from mgd77+ files
  * or (2) add a new data column to mgd77+ files.  Data can be added
  * from data tables, created from reference field formulas, or by
@@ -50,25 +50,24 @@
 
 int main (int argc, char **argv)
 {
-	int var_id, n_dims = 0, dims[2];
-	
-	int i, j, k = 0, ii, jj, argno, n_cruises = 0, n_paths = 0, mx = 0, my, column, result;
-	int width, n_delete = 0, GF_version = MGD77_NOT_SET, n_expected_fields, n_fields = 0;
-	int kind = GMT_IS_FLOAT, MTF_col = 1, set, dist_flag = 2, n_bad;
-	int interpolant = BCR_BICUBIC, check;
+	int cdf_var_id, n_dims = 0, dims[2];		/* netCDF variables should be declared as int */
+	size_t start[2] = {0, 0}, count[2] = {0, 0};	/* NetCDF offset variables are size_t */
 	
+	GMT_LONG i, j, k = 0, ii, jj, argno, n_cruises = 0, n_paths = 0, mx = 0, my, column, result;
+	GMT_LONG width, n_delete = 0, GF_version = MGD77_NOT_SET, n_expected_fields, n_fields = 0;
+	GMT_LONG kind = GMT_IS_FLOAT, MTF_col = 1, set, dist_flag = 2, n_bad;
+	GMT_LONG interpolant = BCR_BICUBIC, check;
 	GMT_LONG n_sampled = 0, n_changed = 0, n = 0, pos;
-	
-	size_t n_alloc = GMT_CHUNK, start[2] = {0, 0}, count[2] = {0, 0};
+	GMT_LONG n_alloc = GMT_CHUNK;
 	
 	time_t now;
 	
 	nc_type c_nc_type;
 	
-	BOOLEAN got_c = FALSE, got_a = FALSE, got_d = FALSE, got_g = FALSE, got_i = FALSE, got_n = FALSE, got_t = FALSE;
-	BOOLEAN error = FALSE, replace = FALSE, delete = FALSE, interpolate = FALSE, transform, verified, force = FALSE;
-	BOOLEAN strings = FALSE, got_grid, got_table, two_cols = FALSE, constant, ok_to_read = TRUE, got_e = FALSE;
-	BOOLEAN ignore_verify = FALSE, e77_skip_mode[N_E77_MODES];
+	GMT_LONG got_c = FALSE, got_a = FALSE, got_d = FALSE, got_g = FALSE, got_i = FALSE, got_n = FALSE, got_t = FALSE;
+	GMT_LONG error = FALSE, replace = FALSE, delete = FALSE, interpolate = FALSE, transform, verified, force = FALSE;
+	GMT_LONG strings = FALSE, got_grid, got_table, two_cols = FALSE, constant, ok_to_read = TRUE, got_e = FALSE;
+	GMT_LONG ignore_verify = FALSE, e77_skip_mode[N_E77_MODES];
 	
 	char line[BUFSIZ], file[BUFSIZ], *d_list = CNULL, p[BUFSIZ], history[BUFSIZ], c_size = 0, **list;
 	char c_abbrev[GMT_TEXT_LEN], c_units[GMT_TEXT_LEN], c_name[MGD77_COL_NAME_LEN], c_comment[MGD77_COL_COMMENT_LEN];
@@ -89,12 +88,12 @@ int main (int argc, char **argv)
 	
 	FILE *fp, *fp_err;
 
-	int decode_A_options (int mode, char *line, char *file, double parameters[]);
-	int decode_I_options (char *line, char *abbrev, char *name, char *units, char *size, char *comment, double parameters[]);
-	int skip_if_missing (char *name, char *file, struct MGD77_CONTROL *F, struct MGD77_DATASET *D);
-	int got_default_answer (char *line, char *answer);
+	GMT_LONG decode_A_options (GMT_LONG mode, char *line, char *file, double parameters[]);
+	GMT_LONG decode_I_options (char *line, char *abbrev, char *name, char *units, char *size, char *comment, double parameters[]);
+	GMT_LONG skip_if_missing (char *name, char *file, struct MGD77_CONTROL *F, struct MGD77_DATASET *D);
+	GMT_LONG got_default_answer (char *line, char *answer);
 
-	argc = GMT_begin (argc, argv);		/* Initialize GMT Machinery */
+	argc = (int)GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	GMT_get_time_system ("unix", &(gmtdefs.time_system));						/* MGD77+ uses GMT's Unix time epoch */
 	GMT_init_time_system_structure (&(gmtdefs.time_system));
 	
@@ -108,7 +107,7 @@ int main (int argc, char **argv)
 	parameters[COL_TYPE]    = 0;	/* netCDF type */
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;
 	d_unit[0] = d_unit[1] = '\0';
-	memset ((void *)e77_skip_mode, 0, (size_t)(N_E77_MODES * sizeof (BOOLEAN)));
+	memset ((void *)e77_skip_mode, 0, (size_t)(N_E77_MODES * sizeof (GMT_LONG)));
 	/* Default e77_skip_mode will apply header and fix corrections if prefix is Y and set all data bits */
 	
 	MGD77_Init (&In);			/* Initialize MGD77 Machinery */
@@ -216,6 +215,7 @@ int main (int argc, char **argv)
 
 				case 'F':	/* Force mode */
 					force = TRUE;
+					break;
 
 				case 'I':	/* Column attribute information */
 					error += decode_I_options (&argv[i][2], c_abbrev, c_name, c_units, &c_size, c_comment, parameters);
@@ -413,7 +413,7 @@ int main (int argc, char **argv)
 	fp_err = (In.verbose_dest == 1) ? GMT_stdout : stderr;
 	
 	if (got_c) {	/* Calculate values to be stored */
-		int version = MGD77_NOT_SET, mfield = 1;
+		GMT_LONG version = MGD77_NOT_SET, mfield = 1;
 		/* "file" is here either m, c, or g[1-4] */
 		if (file[0] == 'm' && file[1] == '\0') {
 			got_c = ADD_IGRF;
@@ -481,7 +481,7 @@ int main (int argc, char **argv)
 		interpolate = (threshold > 0.0);
 	}
 	else if (got_table) {	/* Got a one- or two-column table to read */
-		int n_ave = 0;
+		GMT_LONG n_ave = 0;
 		double last_dnt = -DBL_MAX, sum_z = 0.0;
 		char *not_used = NULL;
 		
@@ -504,10 +504,10 @@ int main (int argc, char **argv)
 		two_cols = (got_d || got_n || got_t);
 		n = (two_cols) ? -1 : 0;
 		n_alloc = GMT_CHUNK;
-		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
-		colvalue = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
+		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
+		colvalue = (double *) GMT_memory (VNULL, n_alloc, sizeof (double), GMT_program);
 		if (two_cols) {	/* Got an abscissae column as well (dnt: d = dist, n = rec number, t = time) */
-			coldnt = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
+			coldnt = (double *) GMT_memory (VNULL, n_alloc, sizeof (double), GMT_program);
 			GMT_io.in_col_type[0] = kind;
 		}
 		if (strings && !two_cols) {	/* Must read strings directly from file since GMT_input would barf */
@@ -518,7 +518,7 @@ int main (int argc, char **argv)
 				width = strlen (word);
 				tmp_string[n] = (char *) GMT_memory (VNULL, (size_t)(width+1), sizeof (char), GMT_program);
 				strcpy (tmp_string[n], word);
-				if (width > LEN) LEN = width;
+				if (width > LEN) LEN = (signed char)width;
 				n++;
 			}
 		}
@@ -537,7 +537,7 @@ int main (int argc, char **argv)
 			if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
 
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n);
 				exit (EXIT_FAILURE);
 			}
 
@@ -564,13 +564,13 @@ int main (int argc, char **argv)
 			else
 				colvalue[n] = in[0];
 			if (!two_cols) n++;
-			if (n == (GMT_LONG)n_alloc) {
+			if (n == n_alloc) {
 				n_alloc <<= 1;
 				if (strings)
 					tmp_string = (char **) GMT_memory ((void *)tmp_string, n_alloc, sizeof (char *), GMT_program);
 				else
-					colvalue = (double *) GMT_memory ((void *)colvalue, (size_t)n_alloc, sizeof (double), GMT_program);
-				if (two_cols) coldnt = (double *) GMT_memory ((void *)coldnt, (size_t)n_alloc, sizeof (double), GMT_program);
+					colvalue = (double *) GMT_memory ((void *)colvalue, n_alloc, sizeof (double), GMT_program);
+				if (two_cols) coldnt = (double *) GMT_memory ((void *)coldnt, n_alloc, sizeof (double), GMT_program);
 			}
 
 			n_fields = GMT_input (fp, &n_expected_fields, &in);
@@ -626,7 +626,7 @@ int main (int argc, char **argv)
 		}
 
 		if (delete) {	/* Must create a new file with everything except the fields to be deleted */
-			int id, c;
+			GMT_LONG id, c;
 			char oldfile[BUFSIZ];
 			
 			if (column != MGD77_NOT_SET) {	/* Get info about this existing column to see if it is compatible with new data */
@@ -709,7 +709,7 @@ int main (int argc, char **argv)
 		}
 
 		if (got_c == ADD_IGRF) {	/* Append IGRF column */
-			int ix, iy, it;
+			GMT_LONG ix, iy, it;
 			double date, *xvar, *yvar, *tvar, IGRF[7];
 			
 			if ((ix = skip_if_missing ("lon",  list[argno], &In, D)) == MGD77_NOT_SET) continue;
@@ -730,7 +730,7 @@ int main (int argc, char **argv)
 		}
 #ifdef USE_CM4	
 		else if (got_c == ADD_CM4) {	/* Append CM4 column */
-			int ix, iy, it;
+			GMT_LONG ix, iy, it;
 			double date, *xvar, *yvar, *tvar;
 			struct MGD77_CM4 CM4;
 			
@@ -753,7 +753,7 @@ int main (int argc, char **argv)
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Estimated CM4 at %ld locations out of %ld for cruise %s\n", GMT_program, n_sampled, D->H.n_records, list[argno]);
 		}
 		else if (got_c == ADD_RMAG4) {	/* Append recomputed residual mag column */
-			int ix, iy, it, im;
+			GMT_LONG ix, iy, it, im;
 			double date, *xvar, *yvar, *tvar, *mvar, IGRF[7];
 			char field[5];
 			
@@ -779,7 +779,7 @@ int main (int argc, char **argv)
 		}
 #endif
 		else if (got_c == ADD_GRAV) {	/* Append IGF column */
-			int ix, iy, use;
+			GMT_LONG ix, iy, use;
 			double *xvar, *yvar;
 			
 			if ((ix = skip_if_missing ("lon", list[argno], &In, D)) == MGD77_NOT_SET) continue;
@@ -797,11 +797,11 @@ int main (int argc, char **argv)
 			yvar = (double *)D->values[iy];
 			colvalue = (double *)GMT_memory (VNULL, (size_t)D->H.n_records, sizeof (double), GMT_program);
 			
-			for (i = 0; i < D->H.n_records; i++) colvalue[i] = MGD77_Theoretical_Gravity (xvar[i], yvar[i], GF_version);
+			for (i = 0; i < D->H.n_records; i++) colvalue[i] = MGD77_Theoretical_Gravity (xvar[i], yvar[i], (int)GF_version);
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Estimated IGRF at %ld locations out of %ld for cruise %s\n", GMT_program, D->H.n_records, D->H.n_records, list[argno]);
 		}
 		else if (got_c == ADD_CARTER) {	/* Append Carter correction column */
-			int ix, iy, it;
+			GMT_LONG ix, iy, it;
 			double *xvar, *yvar, *tvar;
 			
 			if ((ix = skip_if_missing ("lon", list[argno], &In, D)) == MGD77_NOT_SET) continue;
@@ -817,14 +817,14 @@ int main (int argc, char **argv)
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Estimated IGRF at %ld locations out of %ld for cruise %s\n", GMT_program, D->H.n_records, D->H.n_records, list[argno]);
 		}
 		else if (got_c == ADD_RMAG) {	/* Append recomputed residual mag column */
-			int ix, iy, it, im;
+			GMT_LONG ix, iy, it, im;
 			double date, *xvar, *yvar, *tvar, *mvar, IGRF[7];
 			char field[5];
 			
 			if ((ix = skip_if_missing ("lon",  list[argno], &In, D)) == MGD77_NOT_SET) continue;
 			if ((iy = skip_if_missing ("lat",  list[argno], &In, D)) == MGD77_NOT_SET) continue;
 			if ((it = skip_if_missing ("time", list[argno], &In, D)) == MGD77_NOT_SET) continue;
-			sprintf (field, "mtf%d", MTF_col);
+			sprintf (field, "mtf%ld", MTF_col);
 			if ((im = skip_if_missing (field, list[argno], &In, D)) == MGD77_NOT_SET) continue;
 
 			xvar = (double *)D->values[ix];
@@ -842,7 +842,7 @@ int main (int argc, char **argv)
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Estimated recomputed magnetic anomaly at %ld locations out of %ld for cruise %s\n", GMT_program, n_sampled, D->H.n_records, list[argno]);
 		}
 		else if (got_grid) {	/* Sample grid along track (or Mercator-projected) track */
-			int ix, iy;
+			GMT_LONG ix, iy;
 			double *xvar, *yvar;
 			
 			if ((ix = skip_if_missing ("lon", list[argno], &In, D)) == MGD77_NOT_SET) continue;
@@ -891,7 +891,7 @@ int main (int argc, char **argv)
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Appended column data for all %ld records for cruise %s\n", GMT_program, D->H.n_records, list[argno]);
 		}
 		else if (got_d || got_n || got_t) {	/* Got either (time,data) or (dist,data) */
-			int ix, iy, it;
+			GMT_LONG ix, iy, it;
 			double *x = VNULL, *y = VNULL, *d = VNULL;
 			colvalue = (double *) GMT_memory ((void *)colvalue, (size_t)D->H.n_records, sizeof (double), GMT_program);
 			if (got_d) {	/* Must create distances in user's units */
@@ -910,7 +910,7 @@ int main (int argc, char **argv)
 				y = (double *) GMT_memory (VNULL, (size_t)D->H.n_records, sizeof (double), GMT_program);
 				result = GMT_intpol (coldnt, colvalue, n, D->H.n_records, x, y, gmtdefs.interpolant);
 				if (result != 0) {
-					fprintf (stderr, "%s: Error from GMT_intpol near row %d!\n", GMT_program, result+1);
+					fprintf (stderr, "%s: Error from GMT_intpol near row %ld!\n", GMT_program, result+1);
 					exit (EXIT_FAILURE);
 				}
 				memcpy ((void *)colvalue, (void *)y, (size_t)(D->H.n_records * sizeof (double)));
@@ -959,14 +959,15 @@ int main (int argc, char **argv)
 			 * Decode error flags to give bit flag, store in colvalue
 			 */
 			FILE *fp_e;
-			int var_id, item;
+			int cdf_var_id, cdf_adjust;
 			char ID[16], date[16], field[GMT_TEXT_LEN], efile[BUFSIZ], E77[256], timestamp[GMT_TEXT_LEN], answer[BUFSIZ], code[BUFSIZ], YorN, kind;
-			GMT_LONG n_recs, rec, number;
-			int type, it, id, key, n_E77_flags, from, to, day, month, year, adjust;
-			int n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_unprocessed, e_error = 0;
+			GMT_LONG n_recs, rec, number, tz;
+			GMT_LONG type, it, id, key, n_E77_flags, from, to, day, month, year, item;
+			GMT_LONG n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_tz_corr, n_unprocessed, e_error = 0;
 			unsigned int *flags, pattern;
 			size_t length;
-			BOOLEAN has_time, old_flags;
+			GMT_LONG has_time, old_flags, tz_errors = FALSE;
+			short *tz_corr = NULL;
 			struct MGD77_HEADER_PARAMS *P;
 			double rec_time, del_t, value, *tvar = VNULL;
 			
@@ -995,7 +996,7 @@ int main (int argc, char **argv)
 				fprintf(stderr, "%s: ERROR: Could not read record #1 from %s.e77 - aborting\n", GMT_program, list[argno]);
 				e_error++;
 			}
-			sscanf (&line[1], "%*s %s %*s %*s %*s %*s %*s %s %*s %ld", ID, date, &n_recs);
+			sscanf (&line[1], "%*s %s %*s %*s %*s %*s %*s %s %*s %" GMT_LL "d", ID, date, &n_recs);
 			if (strcmp (In.NGDC_id, ID)) {
 				fprintf(stderr, "%s: ERROR: E77 Conflict %s : ID = %s versus %s - aborting\n", GMT_program, efile, ID, In.NGDC_id);
 				e_error++;
@@ -1039,17 +1040,18 @@ int main (int argc, char **argv)
 			
 			e_error = n_unprocessed = 0;
 			while (GMT_fgets (line, BUFSIZ, fp_e)) {
-				if (line[0] == '#' || line[0] == '\n') continue;	/* Comments or blank lines are OK */
+				GMT_chop (line);		/* Rid the world of CR/LF */
+				if (line[0] == '#' || line[0] == '\0') continue;	/* Comments or blank lines are OK */
 				if (line[1] == '-') {		/* Header record */
 					if (!(line[0] == 'Y' || line[0] == 'N') && !ignore_verify) {		/* Unprocessed recommendation? */
 						fprintf (stderr, "%s: UNDECIDED: %s\n", list[argno], line);
 						if (line[0] == '?') n_unprocessed++;
 						e_error++;
 					}
-					sscanf (line, "%c-%c-%[^-]-%[^-]-%d", &YorN, &kind, ID, field, &item);
+					sscanf (line, "%c-%c-%[^-]-%[^-]-%" GMT_LL "d", &YorN, &kind, ID, field, &item);
 				}
 				else				/* Data record */
-					sscanf (line, "%c %s %s %ld %s", &YorN, ID, timestamp, &rec, code);
+					sscanf (line, "%c %s %s %" GMT_LL "d %s", &YorN, ID, timestamp, &rec, code);
 				if (strcmp (In.NGDC_id, ID)) {
 					fprintf(stderr, "%s: ERROR: E77 Conflict %s : ID = %s versus %s in header records!\n", GMT_program, efile, ID, In.NGDC_id);
 					e_error++;
@@ -1075,18 +1077,18 @@ int main (int argc, char **argv)
 			while (GMT_fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Header", (size_t)14));	/* Read until we get to Header record section */
 			
 			flags = (unsigned int *)GMT_memory (VNULL, (size_t)D->H.n_records, sizeof (unsigned int), GMT_program);
-			n_E77_flags = n_E77_headers = n_E77_scales = n_E77_offsets = n_E77_recalcs = 0;
+			n_E77_flags = n_E77_headers = n_E77_scales = n_E77_offsets = n_E77_recalcs = n_tz_corr = 0;
 
 			MGD77_nc_status (nc_open (In.path, NC_WRITE, &In.nc_id));	/* Open the file */
 			MGD77_nc_status (nc_redef (In.nc_id));				/* Enter define mode */
 			old_flags = MGD77_Remove_E77 (&In);				/* Remove any previously revised header parameters */
 			while (GMT_fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Data", (size_t)14)) {	/* Read until we get to data record section */
-				if (line[0] == '#' || line[0] == '\n') continue;	/* Skip comments */
 				GMT_chop (line);					/* Rid the world of CR/LF */
+				if (line[0] == '#' || line[0] == '\0') continue;	/* Skip comments */
 				/* Example of expected line:  
 				   Y-E-06050010-H15-01: Invalid Gravity Departure Base Station Value: (0000000) [1000009]
 				*/
-				sscanf (line, "%c-%c-%[^-]-%[^-]-%d", &YorN, &kind, ID, field, &item);
+				sscanf (line, "%c-%c-%[^-]-%[^-]-%" GMT_LL "d", &YorN, &kind, ID, field, &item);
 				if (strcmp (In.NGDC_id, ID)) {
 					fprintf(stderr, "%s: ERROR: E77 Conflict %s : ID = %s versus %s in header records - skipped\n", GMT_program, efile, ID, In.NGDC_id);
 					e_error++;
@@ -1112,14 +1114,14 @@ int main (int argc, char **argv)
 				
 				if (type == E77_HEADER_MODE) {	/* Header meta data fixes */
 				
-					key = MGD77_Param_Key (number, item);	/* Returns -ve if sequence not found or item not found, >=0 otherwise */
+					key = MGD77_Param_Key ((int)number, (int)item);	/* Returns -ve if sequence not found or item not found, >=0 otherwise */
 					
 					switch (key) {
 						case MGD77_BAD_HEADER_RECNO:
 							fprintf (stderr, "%s: Warning: Sequence number %ld is outside range - skipped\n", GMT_program, number);
 							break;
 						case MGD77_BAD_HEADER_ITEM:
-							fprintf (stderr, "%s: Warning: Sequence number %ld, Item %d is not supported - skipped\n", GMT_program, number, item);
+							fprintf (stderr, "%s: Warning: Sequence number %ld, Item %ld is not supported - skipped\n", GMT_program, number, item);
 							break;
 						default:	/* Update internal structure as well as netCDF file attributes */
 							length = (MGD77_Header_Lookup[key].length == 1) ? 1 : strlen (answer);
@@ -1139,8 +1141,8 @@ int main (int argc, char **argv)
 						switch (number) {
 							case E77_HDR_PDR:	/* Must deal with undetected Precision Depth Recorder wrap-arounds - this also force recalc of depth when data is read*/
 								MGD77_nc_status (nc_put_att_double (In.nc_id, NC_GLOBAL, "PDR_wrap", NC_DOUBLE, (size_t)1, &value));
-								adjust = MGD77_COL_ADJ_TWT;
-								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &adjust));
+								cdf_adjust = MGD77_COL_ADJ_TWT;
+								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &cdf_adjust));
 								n_E77_recalcs++;
 								if ((id = MGD77_Get_Column ("depth", &In)) == MGD77_NOT_SET) {
 									fprintf (stderr, "%s: Warning: Correction implied for %s which is not in this cruise?\n", GMT_program, field);
@@ -1148,23 +1150,23 @@ int main (int argc, char **argv)
 								}
 								/* no break - we want to fall through and also set depth adjustment */
 							case E77_HDR_CARTER:	/* Recalculate Carter depth from twt */
-								adjust = MGD77_COL_ADJ_DEPTH;
-								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &adjust));
+								cdf_adjust = MGD77_COL_ADJ_DEPTH;
+								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &cdf_adjust));
 								n_E77_recalcs++;
 								break;
 							case E77_HDR_ANOM_MAG:	/* Recalculate anomaly mag as mtf1 - igrf */
-								adjust = MGD77_COL_ADJ_MAG;
-								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &adjust));
+								cdf_adjust = MGD77_COL_ADJ_MAG;
+								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &cdf_adjust));
 								n_E77_recalcs++;
 								break;
 							case E77_HDR_ANOM_FAA:	/* Recalculate anomaly faa as gobs - igf */
-								adjust = MGD77_COL_ADJ_FAA;
-								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &adjust));
+								cdf_adjust = MGD77_COL_ADJ_FAA;
+								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &cdf_adjust));
 								n_E77_recalcs++;
 								break;
 							case E77_HDR_ANOM_FAA_EOT:	/* Recalculate anomaly faa as gobs - igf + eot */
-								adjust = MGD77_COL_ADJ_FAA_EOT;
-								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &adjust));
+								cdf_adjust = MGD77_COL_ADJ_FAA_EOT;
+								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &cdf_adjust));
 								n_E77_recalcs++;
 								break;
 							case E77_HDR_SCALE:	/* Correction scale factor */
@@ -1183,7 +1185,7 @@ int main (int argc, char **argv)
 								break;
 							case E77_HDR_GRID_OFFSET:	/* Range of bad values - set flags to BAD  */
 							case E77_HDR_FLAGRANGE:		/* Range of bad values - set flags to BAD  */
-								sscanf (answer, "%d-%d", &from, &to);
+								sscanf (answer, "%" GMT_LL "d-%" GMT_LL "d", &from, &to);
 								if (from < 1 || from > D->H.n_records || to < 1 || to > D->H.n_records || to < from) {
 									fprintf (stderr, "%s: Error: Record range %s is invalid.  Correction skipped\n", GMT_program, answer);
 									break;
@@ -1206,7 +1208,7 @@ int main (int argc, char **argv)
 				for (rec = 0, has_time = FALSE; !has_time && rec < D->H.n_records; rec++) if (!GMT_is_dnan (tvar[rec])) has_time = TRUE;
 			}
 			while (GMT_fgets (line, BUFSIZ, fp_e)) {	/* Read until EOF */
-				sscanf (line, "%c %s %s %ld %s", &YorN, ID, timestamp, &rec, code);
+				sscanf (line, "%c %s %s %" GMT_LL "d %s", &YorN, ID, timestamp, &rec, code);
 				if (strcmp (In.NGDC_id, ID)) {
 					fprintf(stderr, "%s: ERROR: E77 Conflict %s : ID = %s versus %s in data records - skipped\n", GMT_program, efile, ID, In.NGDC_id);
 					e_error++;
@@ -1269,6 +1271,15 @@ int main (int argc, char **argv)
 									flags[rec] |= set_bit(NCPOS_LAT);
 									n_E77_flags++;
 									break;
+								case 'F':	/* Time-zone error */
+									if (!tz_errors) {	/* First time we must allocate tz_corr array */
+										tz_corr = (short *)GMT_memory (VNULL, (size_t)D->H.n_records, sizeof (short), GMT_program);
+										tz_errors = TRUE;
+									}
+									sscanf (line, "%*c %*s %*s %*s %*s %*s %*s %*s %" GMT_LL "d", &tz);
+									tz_corr[rec] = (short)tz;
+									n_tz_corr++;
+									break;
 								default:
 									fprintf (stderr, "%s: Unrecognized NAV code %c - skipped\n", list[argno], p[k]);
 									break;
@@ -1300,14 +1311,21 @@ int main (int argc, char **argv)
 			/* Update E77 history */
 
 			(void) time (&now);
-			sprintf (E77, "%s [%s] E77 corrections applied to header: %d scale: %d offset: %d recalc: %d flags: %d", ctime(&now), In.user, n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_E77_flags);
+			sprintf (E77, "%s [%s] E77 corrections applied to header: %ld scale: %ld offset: %ld recalc: %ld flags: %ld tz_corr: %ld", ctime(&now), In.user, n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_E77_flags, n_tz_corr);
 			for (i = 0; E77[i]; i++) if (E77[i] == '\n') E77[i] = ' ';	/* Remove the \n returned by ctime() */
 			k = strlen (E77);
 			D->H.E77 = (char *)GMT_memory ((void *)D->H.E77, (size_t)(k+1), sizeof (char), GMT_program);
 			strcpy (D->H.E77, E77);
 			MGD77_nc_status (nc_put_att_text (In.nc_id, NC_GLOBAL, "E77", (size_t)k, D->H.E77));
 		
-			old_flags =  (nc_inq_varid (In.nc_id, "MGD77_flags", &var_id) == NC_NOERR);	/* TRUE if flag variable exists already */
+			if (tz_errors) {	/* Use time var_id */
+				MGD77_nc_status (nc_put_att_short (In.nc_id, D->H.info[MGD77_M77_SET].col[0].var_id, "tz_corr", NC_SHORT, (size_t)D->H.n_records, tz_corr));
+				memset ((void *)answer, 0, (size_t)BUFSIZ);	/* No default answer */
+				strcpy (answer, "tz_corr in hours to subtract from UTC");
+				MGD77_nc_status (nc_put_att_text (In.nc_id, D->H.info[MGD77_M77_SET].col[0].var_id, "comment", strlen (answer), answer));
+				GMT_free ((void *)tz_corr);
+			}
+			old_flags =  (nc_inq_varid (In.nc_id, "MGD77_flags", &cdf_var_id) == NC_NOERR);	/* TRUE if flag variable exists already */
 			
 			if (n_E77_flags) {	/* Add flags to netCDF file */
 				if (old_flags) {	/* Flag variable exists already - simply replace existing flags with the new ones */
@@ -1318,16 +1336,16 @@ int main (int argc, char **argv)
 				}
 				else {	/* We need to define the flags for the first time */
 					dims[0] = In.nc_recid;
-					MGD77_nc_status (nc_def_var (In.nc_id, "MGD77_flags", NC_INT, 1, dims, &var_id));	/* Define an array variable */
+					MGD77_nc_status (nc_def_var (In.nc_id, "MGD77_flags", NC_INT, 1, dims, &cdf_var_id));	/* Define an array variable */
 					memset ((void *)answer, 0, (size_t)BUFSIZ);	/* No default answer */
 					strcpy (answer, "MGD77 flags (ON = Bad, OFF = Good) derived from E77 errata");
-					MGD77_nc_status (nc_put_att_text (In.nc_id, var_id, "comment", strlen (answer), answer));
+					MGD77_nc_status (nc_put_att_text (In.nc_id, cdf_var_id, "comment", strlen (answer), answer));
 					D->flags[0] = flags;
 				}
 				MGD77_nc_status (nc_enddef (In.nc_id));	/* End define mode. */
 				start[0] = 0;
 				count[0] = D->H.n_records;
-				MGD77_nc_status (nc_put_vara_int (In.nc_id, var_id, start, count, (int *)D->flags[0]));
+				MGD77_nc_status (nc_put_vara_int (In.nc_id, cdf_var_id, start, count, (int *)D->flags[0]));
 			}
 			else if (old_flags) {	/* Had flags from before which we cannot delete */
 				MGD77_nc_status (nc_enddef (In.nc_id));	/* End define mode. */
@@ -1337,7 +1355,7 @@ int main (int argc, char **argv)
 				start[0] = 0;
 				count[0] = D->H.n_records;
 				memset ((void *)D->flags[0], 0, (size_t)(D->H.n_records * sizeof (int)));	/* Reset all flags to 0 (GOOD) */
-				MGD77_nc_status (nc_put_vara_int (In.nc_id, var_id, start, count, (int *)D->flags[0]));
+				MGD77_nc_status (nc_put_vara_int (In.nc_id, cdf_var_id, start, count, (int *)D->flags[0]));
 			}
 			
 			MGD77_Free (D);
@@ -1396,28 +1414,28 @@ int main (int argc, char **argv)
 		if (column == MGD77_NOT_SET) {	/*Adding a new column */
 			if (constant) {	/* Simply store one value */
 				if (LEN)	/* Text variable */
-					MGD77_nc_status (nc_def_var (In.nc_id, c_abbrev, c_nc_type, 1, &dims[1], &var_id));	/* Define a single text variable */
+					MGD77_nc_status (nc_def_var (In.nc_id, c_abbrev, c_nc_type, 1, &dims[1], &cdf_var_id));	/* Define a single text variable */
 				else
-					MGD77_nc_status (nc_def_var (In.nc_id, c_abbrev, c_nc_type, 0, NULL, &var_id));		/* Define a single variable */
+					MGD77_nc_status (nc_def_var (In.nc_id, c_abbrev, c_nc_type, 0, NULL, &cdf_var_id));		/* Define a single variable */
 			}
 			else {	/* Must store array */
 				if (LEN)	/* Text variable */
-					MGD77_nc_status (nc_def_var (In.nc_id, c_abbrev, c_nc_type, 2, dims, &var_id));		/* Define a 2-D text variable */
+					MGD77_nc_status (nc_def_var (In.nc_id, c_abbrev, c_nc_type, 2, dims, &cdf_var_id));		/* Define a 2-D text variable */
 				else
-					MGD77_nc_status (nc_def_var (In.nc_id, c_abbrev, c_nc_type, 1, dims, &var_id));		/* Define a number array variable */
+					MGD77_nc_status (nc_def_var (In.nc_id, c_abbrev, c_nc_type, 1, dims, &cdf_var_id));		/* Define a number array variable */
 			}
 		}
 		else	/* Reuse, get id */
-			MGD77_nc_status (nc_inq_varid (In.nc_id, c_abbrev, &var_id));
+			MGD77_nc_status (nc_inq_varid (In.nc_id, c_abbrev, &cdf_var_id));
 		
-		if (c_name[0]) MGD77_nc_status (nc_put_att_text   (In.nc_id, var_id, "long_name", strlen (c_name), c_name));
-		if (c_units[0]) MGD77_nc_status (nc_put_att_text   (In.nc_id, var_id, "units", strlen (c_units), c_units));
-		MGD77_nc_status (nc_put_att_double   (In.nc_id, var_id, "actual_range", NC_DOUBLE, (size_t)2, limits));
-		if (c_comment[0]) MGD77_nc_status (nc_put_att_text   (In.nc_id, var_id, "comment", strlen (c_comment), c_comment));
-		MGD77_nc_status (nc_put_att_double (In.nc_id, var_id, "_FillValue", c_nc_type, (size_t)1, &MGD77_NaN_val[c_nc_type]));
-		MGD77_nc_status (nc_put_att_double (In.nc_id, var_id, "missing_value", c_nc_type, (size_t)1, &MGD77_NaN_val[c_nc_type]));
-		if (parameters[COL_SCALE]  != 1.0) MGD77_nc_status (nc_put_att_double (In.nc_id, var_id, "scale_factor", NC_DOUBLE, (size_t)1, &parameters[COL_SCALE]));
-		if (parameters[COL_OFFSET] != 0.0) MGD77_nc_status (nc_put_att_double (In.nc_id, var_id, "add_offset",   NC_DOUBLE, (size_t)1, &parameters[COL_OFFSET]));
+		if (c_name[0]) MGD77_nc_status (nc_put_att_text   (In.nc_id, cdf_var_id, "long_name", strlen (c_name), c_name));
+		if (c_units[0]) MGD77_nc_status (nc_put_att_text   (In.nc_id, cdf_var_id, "units", strlen (c_units), c_units));
+		MGD77_nc_status (nc_put_att_double   (In.nc_id, cdf_var_id, "actual_range", NC_DOUBLE, (size_t)2, limits));
+		if (c_comment[0]) MGD77_nc_status (nc_put_att_text   (In.nc_id, cdf_var_id, "comment", strlen (c_comment), c_comment));
+		MGD77_nc_status (nc_put_att_double (In.nc_id, cdf_var_id, "_FillValue", c_nc_type, (size_t)1, &MGD77_NaN_val[c_nc_type]));
+		MGD77_nc_status (nc_put_att_double (In.nc_id, cdf_var_id, "missing_value", c_nc_type, (size_t)1, &MGD77_NaN_val[c_nc_type]));
+		if (parameters[COL_SCALE]  != 1.0) MGD77_nc_status (nc_put_att_double (In.nc_id, cdf_var_id, "scale_factor", NC_DOUBLE, (size_t)1, &parameters[COL_SCALE]));
+		if (parameters[COL_OFFSET] != 0.0) MGD77_nc_status (nc_put_att_double (In.nc_id, cdf_var_id, "add_offset",   NC_DOUBLE, (size_t)1, &parameters[COL_OFFSET]));
 					
 		/* Update history */
 
@@ -1437,26 +1455,26 @@ int main (int argc, char **argv)
 		n_bad = 0;
 		if (constant) {	/* Simply store one value */
 			if (LEN)
-				MGD77_nc_status (nc_put_vara_schar (In.nc_id, var_id, start, &count[1], (signed char *)text));	/* Just write one text string */
+				MGD77_nc_status (nc_put_vara_schar (In.nc_id, cdf_var_id, start, &count[1], (signed char *)text));	/* Just write one text string */
 			else {
 				n_bad = MGD77_do_scale_offset_before_write (&single_val, colvalue, (size_t)1, parameters[COL_SCALE], parameters[COL_OFFSET], c_nc_type);
-				MGD77_nc_status (nc_put_var1_double (In.nc_id, var_id, start, &single_val));
+				MGD77_nc_status (nc_put_var1_double (In.nc_id, cdf_var_id, start, &single_val));
 			}
 		}
 		else {	/* Must store array */
 			if (LEN)
-				MGD77_nc_status (nc_put_vara_schar (In.nc_id, var_id, start, count, (signed char *)text));
+				MGD77_nc_status (nc_put_vara_schar (In.nc_id, cdf_var_id, start, count, (signed char *)text));
 			else if (transform) {
 				xtmp = (double *) GMT_memory (VNULL, count[0], sizeof (double), GMT_program);
 				n_bad = MGD77_do_scale_offset_before_write (xtmp, colvalue, D->H.n_records, parameters[COL_SCALE], parameters[COL_OFFSET], c_nc_type);
-				MGD77_nc_status (nc_put_vara_double (In.nc_id, var_id, start, count, xtmp));
+				MGD77_nc_status (nc_put_vara_double (In.nc_id, cdf_var_id, start, count, xtmp));
 				GMT_free ((void *)xtmp);
 			}
 			else 
-				MGD77_nc_status (nc_put_vara_double (In.nc_id, var_id, start, count, colvalue));
+				MGD77_nc_status (nc_put_vara_double (In.nc_id, cdf_var_id, start, count, colvalue));
 		}
 		if (n_bad) {	/* Report what we found */
-			if (In.verbose_level | 1) fprintf (fp_err, "%s: %s [%s] had %d values outside valid range <%g,%g> for the chosen type (set to NaN = %g)\n",
+			if (In.verbose_level | 1) fprintf (fp_err, "%s: %s [%s] had %ld values outside valid range <%g,%g> for the chosen type (set to NaN = %g)\n",
 				GMT_program, In.NGDC_id, c_abbrev, n_bad, MGD77_Low_val[c_nc_type], MGD77_High_val[c_nc_type], MGD77_NaN_val[c_nc_type]);
 		}
 		
@@ -1471,14 +1489,14 @@ int main (int argc, char **argv)
 	
 	if (gmtdefs.verbose) {
 		if (delete)
-			fprintf (stderr, "%s: Removed %d data columns from %ld MGD77 files\n", GMT_program, n_delete, n_changed);
+			fprintf (stderr, "%s: Removed %ld data columns from %ld MGD77 files\n", GMT_program, n_delete, n_changed);
 		else if (got_e)
 			fprintf (stderr, "%s: E77 corrections applied to %ld MGD77 files\n", GMT_program, n_changed);
 		else
 			fprintf (stderr, "%s: Sampled data for %ld MGD77 files\n", GMT_program, n_changed);
 	}
 	
-	MGD77_Path_Free (n_paths, list);
+	MGD77_Path_Free ((int)n_paths, list);
 	MGD77_end (&In);
 
 	exit (EXIT_SUCCESS);
@@ -1486,9 +1504,9 @@ int main (int argc, char **argv)
 
 /* Help functions to decode the -A and -I options */
 
-int decode_A_options (int mode, char *line, char *file, double parameters[])
+GMT_LONG decode_A_options (GMT_LONG mode, char *line, char *file, double parameters[])
 {
-	int error = 0, n;
+	GMT_LONG error = 0, n;
 	
 	if (mode == 1) {	/* For *.img files since we need to know data scale and grid mode */
 		/* -A[+]i<filename>,<scale>/<mode>[/<lat>] */
@@ -1503,9 +1521,9 @@ int decode_A_options (int mode, char *line, char *file, double parameters[])
 	return (error);
 }
 
-int decode_I_options (char *line, char *abbrev, char *name, char *units, char *size, char *comment, double parameters[])
+GMT_LONG decode_I_options (char *line, char *abbrev, char *name, char *units, char *size, char *comment, double parameters[])
 {	/* -I<abbrev>/<name>/<units>/<size>/<scale>/<offset>/\"comment\" */
-	int i = 0, k, error;
+	GMT_LONG i = 0, k, error;
 	GMT_LONG pos = 0;
 	char p[BUFSIZ];
 	
@@ -1572,12 +1590,12 @@ int decode_I_options (char *line, char *abbrev, char *name, char *units, char *s
 			parameters[COL_TYPE] = MGD77_NOT_SET;
 			break;
 	}
-	return ((irint (parameters[COL_TYPE]) == MGD77_NOT_SET) || (i != 7));
+	return ((GMT_LONG)(irint (parameters[COL_TYPE]) == MGD77_NOT_SET) || (i != 7));
 }
 
-int skip_if_missing (char *name, char *file, struct MGD77_CONTROL *F, struct MGD77_DATASET *D)
+GMT_LONG skip_if_missing (char *name, char *file, struct MGD77_CONTROL *F, struct MGD77_DATASET *D)
 {	/* Used when a needed column is not present and we must free memory and goto next file */
-	int id;
+	GMT_LONG id;
 
 	if ((id = MGD77_Get_Column (name, F)) == MGD77_NOT_SET) {
 		fprintf (stderr, "%s: Cruise %s is missing column %s which is required for selected operation - skipping\n", GMT_program, file, name);
@@ -1586,9 +1604,9 @@ int skip_if_missing (char *name, char *file, struct MGD77_CONTROL *F, struct MGD
 	return (id);
 }
 
-int got_default_answer (char *line, char *answer)
+GMT_LONG got_default_answer (char *line, char *answer)
 {
-	int i, k, len;
+	GMT_LONG i, k, len;
 	
 	len = strlen(line) - 1;
 	memset ((void *)answer, 0, (size_t)BUFSIZ);	/* No default answer */
