@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77track.c,v 1.69 2010/03/22 18:55:47 guru Exp $
+ *	$Id: mgd77track.c,v 1.70 2010/07/26 22:36:46 guru Exp $
  *
  *    Copyright (c) 2004-2010 by P. Wessel
  *    See README file for copying and redistribution conditions.
@@ -383,10 +383,6 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: Error reading header sequence for cruise %s\n", GMT_program, list[argno]);
 			exit (EXIT_FAILURE);
 		}
-		if (GMT_io.multi_segments[GMT_OUT]) {	/* Write multisegment header between each cruise */
-			sprintf (GMT_io.segment_header, "%c %s\n", GMT_io.EOF_flag[GMT_OUT], list[argno]);
-			GMT_write_segmentheader (GMT_stdout, M.n_out_columns);
-		}
 		rec = 0;
 		last_julian = -1;
 		
