@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtlegs.c,v 1.14 2009/07/11 03:16:31 guru Exp $
+ *	$Id: gmtlegs.c,v 1.17 2010/09/28 20:38:51 remko Exp $
  *
- *    Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -16,7 +16,7 @@
  * Version 2.0: 21-Jun-1991
  * Version 3.2: 10-MAR-1999
  */
- 
+
 #include "gmt.h"
 
 #define MSIZE 64000
@@ -25,7 +25,7 @@ struct INFO {
 	char legname[16];
 	int leg_id;
 	int gmt;
-	BOOLEAN mark;
+	GMT_LONG mark;
 	struct INFO *next_info;
 };
 
@@ -35,7 +35,7 @@ int main (int argc, char **argv)
 	char lname[16], line[BUFSIZ], file[BUFSIZ];
 	double west, east, south, north;
 	FILE *fleg, *fbin;
-	BOOLEAN error = FALSE, full = FALSE, verbose = FALSE, inside(double w, double e, double s, double n, int binnr);
+	GMT_LONG error = FALSE, full = FALSE, verbose = FALSE, inside(double w, double e, double s, double n, int binnr);
 	struct INFO *leginfo[MSIZE], *ptr[MSIZE], *make_info(char *name, int id_no, int flag);
 	static char *data[8] = { "-", "G", "M", "GM", "T", "GT", "MT", "GMT" };
 
@@ -43,7 +43,7 @@ int main (int argc, char **argv)
 
 	west = east = south = north = 0.0;
   	gmtflag = 0;
-  	
+
 	for (i = 1; i < argc; i++) {
   		if (argv[i][0] == '-') {
   			switch(argv[i][1]) {
@@ -85,27 +85,27 @@ int main (int argc, char **argv)
   		fprintf(stderr, "	-V (verbose) prints number of legs found\n");
   		exit (EXIT_FAILURE);
   	}
-  	
-  	sprintf (file, "%s%cmgg%cgmt_legs.d", GMT_SHAREDIR, DIR_DELIM, DIR_DELIM);
+
+  	GMT_getsharepath ("mgg", "gmt_legs", ".d", file);
   	if ((fleg = fopen (file, "r")) == NULL) {
 		fprintf (stderr,"gmtlegs: Could not open %s\n", file);
 		exit (EXIT_FAILURE);
 	}
-  	sprintf (file, "%s%cmgg%cgmt_index.b", GMT_SHAREDIR, DIR_DELIM, DIR_DELIM);
+  	GMT_getsharepath ("mgg", "gmt_index", ".b", file);
 	if ((fbin = fopen (file, "rb")) == NULL) {
 		fprintf(stderr,"gmtlegs: Could not open %s\n", file);
 		exit (EXIT_FAILURE);
 	}
-	
+
 	/* Make sure that WESN is in whole degrees, truncate if necessary */
-	
+
 	west = floor (west);
 	east = ceil (east);
 	south = floor (south);
 	north = ceil (north);
-	
+
 	/* Read info about each leg */
-	
+
 	ninfo = 0;
 	while (fgets (line, BUFSIZ, fleg)) {
 		sscanf (line, "%s %d %d", lname, &no, &flagin);
@@ -114,7 +114,7 @@ int main (int argc, char **argv)
 	fclose (fleg);
 
 	/* Start reading the index-file */
-	
+
 	while (fread ((void *)&bin, (size_t)4, (size_t)1, fbin) != 0) {
 		not_used = fread ((void *)&nlegs, (size_t)4, (size_t)1, fbin);
 		if (inside (west, east, south, north, bin)) {
@@ -129,7 +129,7 @@ int main (int argc, char **argv)
 			fseek(fbin, (long)(nlegs*4), 1);
 	}
 	fclose(fbin);
-	
+
 	for (i = 0; i < ninfo; i++) {
 		if (leginfo[i]->mark) {
 			(full) ? (printf("%s\t%s\n",leginfo[i]->legname,
@@ -154,7 +154,7 @@ struct INFO *make_info(char *name, int id_no, int flag)
 	return (new);
 }
 
-BOOLEAN inside (double w, double e, double s, double n, int binnr)
+GMT_LONG inside (double w, double e, double s, double n, int binnr)
 {
 	double lat, lon;
 	lon = (double) (binnr % 360);
