@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtpath.c,v 1.8 2007/03/14 23:11:11 pwessel Exp $
+ *	$Id: gmtpath.c,v 1.15 2010/09/28 20:23:03 remko Exp $
  *
- *    Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -22,7 +22,7 @@ int main (int argc, char **argv)
 
 	argc = GMT_begin (argc, argv);
 	
-	gmtmggpath_init(GMT_SHAREDIR);
+	gmtmggpath_init();
 
 	for (i = 1; !error && i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -39,6 +39,7 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	gmtmgg_end ();
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
