@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77togmt.c,v 1.28 2010/03/22 18:55:47 guru Exp $
+ *	$Id: mgd77togmt.c,v 1.29 2010/09/28 20:23:03 remko Exp $
  *
  *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
@@ -56,7 +56,7 @@ int main (int argc, char **argv) {
 
 	argc = GMT_begin (argc, argv);
 
-	gmtmggpath_init(GMT_SHAREDIR);
+	gmtmggpath_init();
 
 	legfname = list = mfile = CNULL;
 	memset ((void *)agency, 0, (size_t)10);
