@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt2kml.c,v 1.23 2009/09/14 02:11:05 guru Exp $
+ *	$Id: gmt2kml.c,v 1.32 2010/08/22 07:36:48 guru Exp $
  *
- *	Copyright (c) 2009 by P. Wessel
+ *	Copyright (c) 2009-2010 by P. Wessel
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -44,7 +44,7 @@ struct EXT_COL {
 	char name[GMT_TEXT_LEN];	/* Name of this column */
 };
 
-BOOLEAN check_lon_lat (double *lon, double *lat, double west, double east, double north, double south);
+GMT_LONG check_lon_lat (double *lon, double *lat, double west, double east, double north, double south);
 void print_altmode (int extrude, int fmode, int altmode);
 void place_region_tag (double west, double east, double south, double north, double alt_min, double alt_max, GMT_LONG lod_min, GMT_LONG lod_max, double fade_min, double fade_max);
 GMT_LONG ascii_output_one (double x, GMT_LONG col);
@@ -55,11 +55,11 @@ int main (int argc, char **argv)
 	GMT_LONG ix, iy, t1_col, t2_col, pos, t_itransp, n_ext_cols = 0, n_alloc = 0, n_rec = 0;
 	GMT_LONG lod_min = 0, lod_max = 0, set_nr = 0, pnt_nr = 0, index = -4;
 
-	BOOLEAN error = FALSE, long_verbose = FALSE, nofile = TRUE, done = FALSE, greenwich = FALSE, first = TRUE;
-	BOOLEAN get_label = FALSE, no_label = FALSE, visible = TRUE, open = FALSE, use_folder = FALSE;
-	BOOLEAN add_description = FALSE, get_actual_wesn = FALSE, do_pen = TRUE, do_fill = TRUE, get_z = FALSE, get_alt = FALSE, get_rgb = FALSE, extrude = FALSE;
+	GMT_LONG error = FALSE, long_verbose = FALSE, nofile = TRUE, done = FALSE, greenwich = FALSE, first = TRUE;
+	GMT_LONG get_label = FALSE, no_label = FALSE, visible = TRUE, open = FALSE, use_folder = FALSE, format_label = FALSE;
+	GMT_LONG add_description = FALSE, get_actual_wesn = FALSE, do_pen = TRUE, do_fill = TRUE, get_z = FALSE, get_alt = FALSE, get_rgb = FALSE, extrude = FALSE;
 	
-	char doc_title[BUFSIZ], folder_name[BUFSIZ], icon[BUFSIZ];
+	char doc_title[BUFSIZ], folder_name[BUFSIZ], icon[BUFSIZ], description[BUFSIZ];
 	char *feature[5] = {"Point", "Point", "Point", "LineString", "Polygon"}, *name[5] = {"Point", "Event", "Timespan", "Line", "Polygon"};
 	char *indent[5] = {"\t\t\t", "\t\t\t", "\t\t\t", "\t\t\t", "\t\t\t\t\t"}, *fmt = NULL, buffer[BUFSIZ], label[BUFSIZ];
 	char *Document[2] = {"Document", "Folder"}, p[BUFSIZ], C[4][GMT_TEXT_LEN], *c;
@@ -76,7 +76,7 @@ int main (int argc, char **argv)
 	struct GMT_PEN pen;
 	struct EXT_COL *D = NULL;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	GMT_io.in_col_type[GMT_X] = GMT_io.out_col_type[GMT_X] = GMT_IS_LON;
 	GMT_io.in_col_type[GMT_Y] = GMT_io.out_col_type[GMT_Y] = GMT_IS_LAT;
@@ -217,7 +217,7 @@ int main (int argc, char **argv)
 				case 'L':	/* Extended data */
 					pos = n_ext_cols = 0;
 					while ((GMT_strtok (&argv[i][2], ",", &pos, p))) {
-						for (k = 0; p[k] && p[k] != ':'; k++);	/* FInd position of colon */
+						for (k = 0; p[k] && p[k] != ':'; k++);	/* Find position of colon */
 						p[k] = ' ';
 						if (n_ext_cols == n_alloc) n_alloc = GMT_alloc_memory ((void **)&D, n_ext_cols, n_alloc, sizeof (struct EXT_COL), GMT_program);
 						sscanf (p, "%d %[^:]", &D[n_ext_cols].col, D[n_ext_cols].name);
@@ -232,8 +232,10 @@ int main (int argc, char **argv)
 						t_transp = 0.0;
 						no_label = TRUE;
 					}
-					else
+					else {
 						fmt = &argv[i][2];
+						format_label = TRUE;
+					}
 					break;
 				case 'Q':	/* Transparency for symbols, lines, and polygons */
 					switch (argv[i][2]) {
@@ -488,7 +490,7 @@ int main (int argc, char **argv)
 	/* Set shared line and polygon style (also for extrusions) */
 	printf ("\t\t<LineStyle>\n\t\t\t<color>%2.2x%2.2x%2.2x%2.2x</color>\n\t\t\t<width>%d</width>\n\t\t</LineStyle>\n",
 		(unsigned int)itransp[LINE], (unsigned int)pen.rgb[2], (unsigned int)pen.rgb[1], (unsigned int)pen.rgb[0], irint (pen.width));
-	printf ("\t\t<PolyStyle>\n\t\t\t<color>%2.2x%2.2x%2.2x%2.2x</color>\n\t\t\t<fill>%d</fill>\n\t\t\t<outline>%d</outline>\n\t\t</PolyStyle>\n",
+	printf ("\t\t<PolyStyle>\n\t\t\t<color>%2.2x%2.2x%2.2x%2.2x</color>\n\t\t\t<fill>%ld</fill>\n\t\t\t<outline>%ld</outline>\n\t\t</PolyStyle>\n",
 		(unsigned int)itransp[POLYGON], (unsigned int)fill.rgb[2], (unsigned int)fill.rgb[1], (unsigned int)fill.rgb[0], do_fill, do_pen);
 
 	/* Set style for labels */
@@ -601,11 +603,11 @@ int main (int argc, char **argv)
 				else if (fmode == EVENT) printf ("\t\t<TimeStamp>\n\t\t\t<when>%s</when>\n\t\t</TimeStamp>\n", C[t1_col]);
 				printf ("\t\t<styleUrl>#GMT%ld</styleUrl>\n", index);
 				printf ("\t\t<%s>\n", feature[fmode]);
-				print_altmode (extrude, FALSE, altmode);
+				print_altmode ((int)extrude, FALSE, (int)altmode);
 				printf ("\t\t\t<coordinates>");
 				ascii_output_one (out[GMT_X], GMT_X);	printf (",");
 				ascii_output_one (out[GMT_Y], GMT_Y);	printf (",");
-				ascii_output_one (out[GMT_Z], GMT_Z);	printf ("\n");
+				ascii_output_one (out[GMT_Z], GMT_Z);
 				printf ("</coordinates>\n");
 				printf ("\t\t</%s>\n", feature[fmode]);
 				printf ("\t</Placemark>\n");
@@ -648,16 +650,17 @@ int main (int argc, char **argv)
 					else {
 						printf ("\t<Placemark>\n");
 						if (no_label) { /* Nothing */ }
-						else if (line->segment[i]->label)
-							printf ("\t\t<name>%s</name>\n", line->segment[i]->label);
-						else if (fmt) {
+						else if (format_label) {
 							printf ("\t\t<name>"); printf (fmt, (int)set_nr); printf ("</name>\n");
 						}
+						else if (line->segment[i]->label)
+							printf ("\t\t<name>%s</name>\n", line->segment[i]->label);
 						else
 							printf ("\t\t<name>%s %ld</name>\n", name[fmode], set_nr);
+						if (GMT_parse_segment_item (line->segment[i]->header, "-D", description)) printf ("\t\t<description>%s</description>\n", description);
 						printf ("\t\t<styleUrl>#GMT%ld</styleUrl>\n", index);
 						printf ("\t\t<%s>\n", feature[fmode]);
-						print_altmode (extrude, fmode, altmode);
+						print_altmode ((int)extrude, (int)fmode, (int)altmode);
 						if (fmode == POLYGON) {
 							printf ("\t\t\t<outerBoundaryIs>\n\t\t\t\t<LinearRing>\n");
 							if (line->segment[i]->min[GMT_X] < 180.0 && line->segment[i]->max[GMT_X] > 180.0) {
@@ -673,22 +676,25 @@ int main (int argc, char **argv)
 					if (fmode < LINE) {
 						printf ("\t\t<Placemark>\n");
 						if (no_label) { /* Nothing */ }
-						else if (line->segment[i]->label)
-							printf ("\t\t\t<name>%s %ld</name>\n", line->segment[i]->label, j);
-						else if (fmt) {
+						else if (format_label) {
 							printf ("\t\t\t<name>"); printf (fmt, (int)pnt_nr); printf ("</name>\n");
 						}
+						else if (line->segment[i]->label && line->segment[i]->n_rows > 1)
+							printf ("\t\t\t<name>%s %ld</name>\n", line->segment[i]->label, j);
+						else if (line->segment[i]->label)
+							printf ("\t\t\t<name>%s</name>\n", line->segment[i]->label);
 						else
 							printf ("\t\t\t<name>%s %ld</name>\n", name[fmode], pnt_nr);
+						if (line->segment[i]->n_rows == 1 && GMT_parse_segment_item (line->segment[i]->header, "-D", description)) printf ("\t\t<description>%s</description>\n", description);
 						if (n_ext_cols) {
-							printf ("\t\t\t<ExtendedData>>\n");
+							printf ("\t\t\t<ExtendedData>\n");
 							for (k = 0; k < n_ext_cols; k++) {
 								printf ("\t\t\t\t<Data name = \"%s\">\n", D[k].name);
 								printf ("\t\t\t\t\t<value>");
 								ascii_output_one (line->segment[i]->coord[D[k].col][j], D[k].col);
 								printf ("</value>\n\t\t\t\t</Data>\n");
 							}
-							printf ("\t\t\t</ExtendedData>>\n");
+							printf ("\t\t\t</ExtendedData>\n");
 						}
 						if (fmode == SPAN) {
 							printf ("\t\t\t<TimeSpan>\n");
@@ -711,11 +717,11 @@ int main (int argc, char **argv)
 						}
 						printf ("\t\t\t<styleUrl>#GMT%ld</styleUrl>\n", index);
 						printf ("\t\t\t<%s>\n\t", feature[fmode]);
-						print_altmode (extrude, FALSE, altmode);
+						print_altmode ((int)extrude, FALSE, (int)altmode);
 						printf ("\t\t\t\t<coordinates>");
 						ascii_output_one (out[GMT_X], GMT_X);	printf (",");
 						ascii_output_one (out[GMT_Y], GMT_Y);	printf (",");
-						ascii_output_one (out[GMT_Z], GMT_Z);	printf ("\n");
+						ascii_output_one (out[GMT_Z], GMT_Z);
 						printf ("</coordinates>\n");
 						printf ("\t\t\t</%s>\n", feature[fmode]);
 						printf ("\t\t</Placemark>\n");
@@ -760,7 +766,7 @@ int main (int argc, char **argv)
 	exit (EXIT_SUCCESS);
 }
 
-BOOLEAN check_lon_lat (double *lon, double *lat, double west, double east, double south, double north)
+GMT_LONG check_lon_lat (double *lon, double *lat, double west, double east, double south, double north)
 {
 	if (*lat < south || *lat > north) return (TRUE);
 	if (*lon < west) *lon += 360.0;
