@@ -1,5 +1,5 @@
 /*
- *	$Id: gmtstitch.c,v 1.60 2010/06/25 20:33:49 guru Exp $
+ *	$Id: gmtstitch.c,v 1.62 2010/09/03 19:42:47 guru Exp $
  *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  */
 /* gmtstitch will combine pieces of coastlines or similar segments into a
@@ -340,17 +340,17 @@ int main (int argc, char **argv)
 			}
 		}
 	}
-	ns = id;
-	if (ns == 0) {	/* All are closed */
-		if (gmtdefs.verbose) fprintf (stderr, "%s: All segments already form closed polygons\n", GMT_program);
-		exit (EXIT_SUCCESS);
-	}
-	if (separate && gmtdefs.verbose) {	/* Report and exit */
-		fprintf (stderr, "%s: Separated %ld closed and %ld open segments\n", GMT_program, n_closed, n_open);
+	if (separate) {	/* Report and exit */
+		if (gmtdefs.verbose) fprintf (stderr, "%s: Separated %ld closed and %ld open segments\n", GMT_program, n_closed, n_open);
 		GMT_free_dataset (D);
-
 		exit (EXIT_SUCCESS);
 	}
+	if (id == -1) {	/* All are closed or we wrote them out as separate */
+		if (gmtdefs.verbose) fprintf (stderr, "%s: All %ld segments already form closed polygons\n", GMT_program, n_closed);
+		GMT_free_dataset (D);
+		exit (EXIT_SUCCESS);
+	}
+	ns = id;
 	
 	if (ns < n_id_alloc) seg = (struct LINK *) GMT_memory ((void *)seg, (size_t)ns, sizeof(struct LINK), GMT_program);
 	skip = (GMT_LONG *) GMT_memory (VNULL, (size_t)ns, sizeof(GMT_LONG), GMT_program);
