@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psmegaplot.c,v 1.16 2009/09/09 23:27:04 guru Exp $
+ *	$Id: psmegaplot.c,v 1.18 2010/03/22 18:55:47 guru Exp $
  *
- *      Copyright (c) 1999-2009 by P. Wessel
+ *      Copyright (c) 1999-2010 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -36,7 +36,7 @@ int main (int argc, char **argv)
 	GMT_LONG x0, y0, i, j, nx, ny, page;
 	double scale = 0.0;
 	FILE *fp;
-	BOOLEAN first, crop_marks = FALSE, error = FALSE, done;
+	GMT_LONG first, crop_marks = FALSE, error = FALSE, done;
 	char ifile[100], buffer[BUFSIZ];
 
 	for (i = 1; i < argc; i++) {
