@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: pssegy.c,v 1.29 2009/07/10 00:23:54 guru Exp $
+ *	$Id: pssegy.c,v 1.31 2010/07/30 21:18:36 guru Exp $
  *
  *    Copyright (c) 1999-2009 by T. Henstock
  *    See README file for copying and redistribution conditions.
@@ -8,7 +8,7 @@
  * uses the GMT pslib imagemask routines to plot a
  * 1-bit depth bitmap which will not obliterate stuff underneath!
  *
- * Author:	Tim Henstock (then@soc.soton.ac.uk)
+ * Author:	Tim Henstock (then@noc.soton.ac.uk)
  * Date:	1-July-1996
  * Version:	1.0
  *
@@ -71,7 +71,6 @@ int main (int argc, char **argv)
 	float *data;
 	SEGYHEAD *header;
 	char *head;
-	/* long *head2;  edited to correct bug when reading trace locations from arbitrary trace header locations*/
 	int head2;
 	SEGYREEL binhead;
 
@@ -364,11 +363,11 @@ use a few of these*/
 	while ((ix<n_traces) && (header = get_segy_header(fpi))){   /* read traces one by one */
 
 		if (plot_offset){ /* plot traces by offset, cdp, or input order */
-			long offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
+			int32_t offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
 			x0 = (double) offset;
 		}
 		else if (plot_cdp){
-			long cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
+			int32_t cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
 			x0 = (double) cdpval;
 		}
 		else if (byte_x){ /* ugly code - want to get value starting at byte_x of header into a double... */
