@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: pssegyz.c,v 1.35 2009/07/10 00:23:54 guru Exp $
+ *	$Id: pssegyz.c,v 1.37 2010/07/30 21:18:36 guru Exp $
  *
  *    Copyright (c) 1999-2009 by T. Henstock
  *    See README file for copying and redistribution conditions.
@@ -8,7 +8,7 @@
  * uses routines from the GMT pslib (the postscript imagemask for plotting a
  * 1-bit depth bitmap which will not obliterate stuff underneath!
  *
- * Author:	Tim Henstock (Timothy.J.Henstock@soc.soton.ac.uk)
+ * Author:	Tim Henstock (then@noc.soton.ac.uk)
  * Date:	17-Nov-97
  * Version:	1.0
  *
@@ -78,7 +78,6 @@ int main (int argc, char **argv)
 	char input[512];
 	char *text;
 	char *head;
-	/* long *head2;  edited to correct bug when reading trace locations from arbitrary trace header locations*/
 	int head2;
 
 
@@ -403,11 +402,11 @@ use a few of these*/
 	while ((ix<n_traces) && (header = get_segy_header(fpi))){   /* read traces one by one */
 	/* check true location header for x */
 		if (xplot_offset){ /* plot traces by offset, cdp, or input order */
-			long offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
+			int32_t offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
 			x0 = (double) offset;
 		}
 		else if (xplot_cdp){
-			long cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
+			int32_t cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
 			x0 = (double) cdpval;
 		}
 		else if (byte_x){ /* ugly code - want to get value starting at byte_x of header into a double... */
@@ -423,11 +422,11 @@ use a few of these*/
 
 	/* now do same for y */
 		if (yplot_offset){ /* plot traces by offset, cdp, or input order */
-			long offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
+			int32_t offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
 			y0 = (double) offset;
 		}
 		else if (yplot_cdp){
-			long cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
+			int32_t cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
 			y0 = (double) cdpval;
 		}
 		else if (byte_y){
