@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: backtracker.c,v 1.46 2009/07/11 03:16:31 guru Exp $
+ *	$Id: backtracker.c,v 1.57 2010/09/08 03:07:39 guru Exp $
  *
- *   Copyright (c) 1999-2009 by P. Wessel
+ *   Copyright (c) 1999-2010 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -64,54 +64,57 @@
 
 int main (int argc, char **argv)
 {
-	struct EULER *p;		/* Pointer to array of stage poles */
+	struct EULER *p;			/* Pointer to array of stage poles */
 
 	GMT_LONG n_points;			/* Number of data points read */
 	GMT_LONG n_chunk;			/* Total length or array returned by libeuler functions */
 	GMT_LONG n_track;			/* Number of points in a track segment */
 	GMT_LONG n_stages = 0;			/* Number of stage poles */
 	GMT_LONG n_segments;			/* Number of path segments written out */
-	GMT_LONG n_skipped = 0;		/* Number of points skipped because t < 0 */
-	int track_limit = 0;		/* Flag for limiting the output track extent [no limit] */
-	int n_args;
-	int n_files = 0, fno;
-	int n_fields, n_expected_fields;
+	GMT_LONG n_skipped = 0;			/* Number of points skipped because t < 0 */
+	GMT_LONG track_limit = 0;		/* Flag for limiting the output track extent [no limit] */
+	GMT_LONG n_m = 0;			/* Number of points in hotspot drift table, if used */
+	GMT_LONG n_args, nm_alloc;
+	GMT_LONG n_files = 0, fno;
+	GMT_LONG n_fields, n_expected_fields;
 	GMT_LONG n_read = 0;
-	int n_out;
-
+	GMT_LONG n_out;
 	GMT_LONG i, j, k;			/* Misc. counters */
 
-	BOOLEAN error = FALSE;		/* Set to TRUE if arguments are inconsistent */
-	BOOLEAN flowline = FALSE;	/* TRUE means we want flowlines, FALSE we want hotspot tracks */
-	BOOLEAN forward = FALSE;	/* TRUE we go FROM hotspot to seamount, FALSE is reverse */
-	BOOLEAN make_path = FALSE;	/* TRUE means create continuous path, FALSE works on discrete points */
-	BOOLEAN seg_files = FALSE;	/* TRUE will write individual files for each segment */
-	BOOLEAN finite = FALSE;		/* TRUE if stage pole file contains finite rotation poles instead */
-	BOOLEAN fix_all = FALSE;	/* TRUE is all data shall be of a fixed age */
-	BOOLEAN stage_id = FALSE;
-	BOOLEAN first = TRUE;
-	BOOLEAN done = FALSE;
-	BOOLEAN nofile = TRUE;
-	BOOLEAN confidence = FALSE;
-	BOOLEAN finite_out = FALSE;	/* FALSE unless -W is set */
-	BOOLEAN single_rotation = FALSE;	/* FALSE unless -F is set */
-	BOOLEAN do_track = FALSE;	/* TRUE if -L is used */
+	GMT_LONG error = FALSE;		/* Set to TRUE if arguments are inconsistent */
+	GMT_LONG flowline = FALSE;	/* TRUE means we want flowlines, FALSE we want hotspot tracks */
+	GMT_LONG forward = FALSE;	/* TRUE we go FROM hotspot to seamount, FALSE is reverse */
+	GMT_LONG make_path = FALSE;	/* TRUE means create continuous path, FALSE works on discrete points */
+	GMT_LONG seg_files = FALSE;	/* TRUE will write individual files for each segment */
+	GMT_LONG finite = FALSE;	/* TRUE if stage pole file contains finite rotation poles instead */
+	GMT_LONG fix_all = FALSE;	/* TRUE is all data shall be of a fixed age */
+	GMT_LONG stage_id = FALSE;
+	GMT_LONG first = TRUE;
+	GMT_LONG done = FALSE;
+	GMT_LONG nofile = TRUE;
+	GMT_LONG confidence = FALSE;
+	GMT_LONG finite_out = FALSE;	/* FALSE unless -W is set */
+	GMT_LONG single_rotation = FALSE;	/* FALSE unless -e is set */
+	GMT_LONG do_track = FALSE;	/* TRUE if -L is used */
 
 	double d_km = 0.0;		/* Step interval along calculated tracks */
 	double t_zero = 0.0;		/* Current age in Ma */
-	double t_fix = 0.0;			/* Fixed age in Ma */
+	double t_fix = 0.0;		/* Fixed age in Ma */
 	double upper_age = 0.0;		/* Extend oldest age back to this time, in Ma */
 	double *c;			/* Array of track chunks returned by libeuler routines */
 	double lon, lat;		/* Seamounts location in decimal degrees */
-	double age;			/* Age of seamount, in Ma */
+	double *dlon = NULL, *dlat = NULL, *dt = NULL;	/* Drifting hotspot locations (t) in decimal degrees */
+	double age, t;			/* Age of seamount, in Ma */
 	double *in, *out;		/* i/o arrays used by GMT */
 	double t_low, t_high;		/* upper/lower age/stage to ouput for track segments */
+	double t_end;
 	double rot_lon, rot_lat, rot_w;	/* A finite rotation */
 	double R[3][3];			/* Rotation matrix */
 	double x[3], y[3];		/* Two 3-D unit vectors */
 
 	char *euler_file = CNULL;	/* Name pointer for file with stage poles */
 	char *file_stem = CNULL;	/* Name pointer for file stem for individual track files */
+	char *drift_file = CNULL;	/* Name pointer for file with hotspot motion */
 	char buffer[BUFSIZ];		/* Input buffer for reading data */
 	char type[50];			/* What kind of line (flowline or hotspot track) */
 	char dir[8];			/* From or To */
@@ -126,7 +129,7 @@ int main (int argc, char **argv)
 
 	out = (double *)NULL;
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 #ifdef DEBUG
 	if (gmtdefs.verbose) fprintf (stderr, "DEBUG mode\n");
@@ -219,6 +222,10 @@ int main (int argc, char **argv)
 					error += GMT_verify_expectations (GMT_io.in_col_type[1], GMT_scanf_arg (txt_b, GMT_io.in_col_type[1], &rot_lat), txt_b);
 					break;
 
+				case 'F':	/* File with hotspot motions */
+					drift_file  = &argv[i][2];
+					break;
+
 				case 'Q':	/* Fixed age for all points */
 					t_fix = atof (&argv[i][2]);
 					fix_all = TRUE;
@@ -260,7 +267,7 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "%s %s - Forward and backward flowlines and hotspot tracks\n\n", GMT_program, SPOTTER_VERSION);
-		fprintf (stderr, "usage: %s [infile(s)] -E<euler.d> OR -eplon/plat/prot [-A[young/old]] [-C] [-Df|b] [%s] [-Lf|b<d_km>]\n", GMT_program, GMT_H_OPT);
+		fprintf (stderr, "usage: %s [infile(s)] -E<euler.d> OR -eplon/plat/prot [-A[young/old]] [-C] [-Df|b] [-F<driftfile] [%s] [-Lf|b<d_km>]\n", GMT_program, GMT_H_OPT);
 		fprintf (stderr, "\t[-N<upper_age>] [-Q<t_fix>] [-S<stem>] [-T<t_zero>] [-V] [-W] [%s] [%s] [%s]\n\n", GMT_t_OPT, GMT_b_OPT, GMT_m_OPT);
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -275,6 +282,10 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-C The file given with -E contains finite rotation poles [Default is stage poles]\n");
 		fprintf (stderr, "\t-Db Backtrack mode: move forward in time (from older to younger positions) [Default]\n");
 		fprintf (stderr, "\t-Df Flowline mode: move backward in time (from younger to older positions)\n");
+		fprintf (stderr, "\t-F file with lon, lat, time records describing motion of hotspot responsible for)\n");
+		fprintf (stderr, "\t   the seamount/path we are concerned with [fixed hotspots].  If given, then the)\n");
+		fprintf (stderr, "\t   input lon, lat is replaced by the position of the drifting hotspot at the given age.)\n");
+		fprintf (stderr, "\t   If -F is used the <d_km> in -L is assumed to be point spacing in Ma.)\n");
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-Lb Compute hotspot tracks sampled every <d_km> interval [Default projects single points].\n");
 		fprintf (stderr, "\t-Lf Compute flowline for seamounts of unknown but maximum age [Default projects single points]\n");
@@ -323,11 +334,38 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: Expects %ld-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
+	GMT_lat_swap_init ();	/* Initialize auxiliary latitude machinery */
+	
+	if (drift_file && (fp = fopen (drift_file, "r")) != NULL) {
+		nm_alloc = GMT_SMALL_CHUNK;
+		dlon = (double *) GMT_memory (VNULL, (size_t)nm_alloc, sizeof (double), GMT_program);
+		dlat = (double *) GMT_memory (VNULL, (size_t)nm_alloc, sizeof (double), GMT_program);
+		dt   = (double *) GMT_memory (VNULL, (size_t)nm_alloc, sizeof (double), GMT_program);
+		k = 0;
+		while (fgets (buffer, 512, fp) != NULL) {
+			if (buffer[0] == '#' || buffer[0] == '\n') continue;
+			sscanf (buffer, "%lf %lf %lf", &dlon[k], &dlat[k], &dt[k]);
+			dlat[k] = GMT_lat_swap (dlat[k], GMT_LATSWAP_G2O);	/* Convert to geocentric */
+			k++;
+			if (k == nm_alloc) {
+				nm_alloc <<= 1;
+				dlon = (double *) GMT_memory ((void *)dlon, (size_t)nm_alloc, sizeof (double), GMT_program);
+				dlat = (double *) GMT_memory ((void *)dlat, (size_t)nm_alloc, sizeof (double), GMT_program);
+				dt   = (double *) GMT_memory ((void *)dt,   (size_t)nm_alloc, sizeof (double), GMT_program);
+			}
+		}
+		GMT_fclose (fp);
+		n_m = k;
+		dlon = (double *) GMT_memory ((void *)dlon, (size_t)k, sizeof (double), GMT_program);
+		dlat = (double *) GMT_memory ((void *)dlat, (size_t)k, sizeof (double), GMT_program);
+		dt   = (double *) GMT_memory ((void *)dt,   (size_t)k, sizeof (double), GMT_program);
+	}
+		
 	if (single_rotation) {	/* Get rotation matrix R */
 		spotter_make_rot_matrix (rot_lon, rot_lat, rot_w, R);
 	}
 	else {	/* Load in the stage poles */
-		n_stages = spotter_init (euler_file, &p, flowline, finite, finite_out, &upper_age, gmtdefs.verbose);
+		n_stages = spotter_init (euler_file, &p, (int)flowline, finite, finite_out, &upper_age, gmtdefs.verbose);
 		spot_func = ((flowline + forward) == 1) ? spotter_forthtrack : spotter_backtrack;
 
 		if (fabs (d_km) > GMT_SMALL) {		/* User wants to interpolate tracks rather than project individual points */
@@ -357,7 +395,8 @@ int main (int argc, char **argv)
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 3 + ((track_limit == 2) ? 2 : 0);
 	if (fix_all && !GMT_io.ncol[GMT_IN]) n_expected_fields = 2;	/* Lon, lat only; use fixed t */
 	if (confidence) n_out = 5 + !(conf_flag == 0);
-	if (single_rotation && !GMT_io.binary[GMT_IN]) n_expected_fields = BUFSIZ;	/* Allow any input for -F mode */
+	if (single_rotation && !GMT_io.binary[GMT_IN]) n_expected_fields = GMT_MAX_COLUMNS;	/* Allow any input for -F mode */
+	if (do_track) GMT_io.multi_segments[GMT_OUT] = TRUE;	/* Since we are producing segments */
 
 	for (fno = 1; !done && fno < n_args; fno++) {	/* Loop over input files, if any */
 		if (!nofile && argv[fno][0] == '-') continue;
@@ -377,7 +416,7 @@ int main (int argc, char **argv)
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
 				not_used = GMT_fgets (buffer, BUFSIZ, fp);
-				if (first && !GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", buffer);
+				if (first && !GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) GMT_fputs (buffer, GMT_stdout);
 			}
 			first = FALSE;
 		}
@@ -392,16 +431,19 @@ int main (int argc, char **argv)
 			if (GMT_io.status & GMT_IO_EOF) continue;
 
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
 				continue;
 			}
 			
 			if (!out) out = (double *) GMT_memory (VNULL, (size_t)MAX(n_out, n_expected_fields), sizeof (double), GMT_program);
 
+			in[GMT_Y] = GMT_lat_swap (in[GMT_Y], GMT_LATSWAP_G2O);	/* Convert to geocentric */
+
 			if (single_rotation) {	/* Simple reconstruction, then exit */
 				GMT_geo_to_cart (in[GMT_Y], in[GMT_X], x, TRUE);	/* Get x-vector */
 				spotter_matrix_vect_mult (R, x, y);			/* Rotate the x-vector */
 				GMT_cart_to_geo (&out[GMT_Y], &out[GMT_X], y, TRUE);	/* Recover lon lat representation; TRUE to get degrees */
+				out[GMT_Y] = GMT_lat_swap (out[GMT_Y], GMT_LATSWAP_O2G);	/* Convert back to geodetic */
 				memcpy ((void *)&out[GMT_Z], (void *)&in[GMT_Z], (n_fields - 2) * sizeof (double));
 				GMT_output (fpo, n_fields, out);
 				continue;
@@ -413,8 +455,15 @@ int main (int argc, char **argv)
 				continue;
 			}
 
-			lon = in[0] * D2R;
-			lat = in[1] * D2R;
+			if (n_m) {	/* Must account for hotspot drift */
+				GMT_intpol (dt, dlon, n_m, 1, &age, &lon, gmtdefs.interpolant);
+				GMT_intpol (dt, dlat, n_m, 1, &age, &lat, gmtdefs.interpolant);
+			}
+			else {	/* Use intput location */
+				lon = in[0];
+				lat = in[1];
+			}
+			lon *= D2R;	lat *= D2R;
 			if (track_limit) {
 				if (track_limit == 2) t_low = in[3], t_high = in[4];
 				age = t_high;	/* No point working more than necessary */
@@ -428,8 +477,6 @@ int main (int argc, char **argv)
 				continue;
 			}
 
-			if (!confidence) n_chunk = (*spot_func) (&lon, &lat, &age, 1, p, n_stages, d_km, t_zero, TRUE + stage_id, NULL, &c);
-
 			if (make_path) {	/* Asked for paths, now write out several multiple segment tracks */
 				if (seg_files) {
 					sprintf (buffer, "%s.%ld", file_stem, n_points);
@@ -439,16 +486,58 @@ int main (int argc, char **argv)
 					}
 					out[3] = (double)n_points;	/* Put the seamount id number in 4th column */
 				}
-				i = 0;
-				n_track = irint (c[i++]);
 				sprintf (GMT_io.segment_header, "> %s %s %g %g\n", type, dir, in[0], in[1]);
 				GMT_write_segmentheader (fpo, n_out);
-				for (j = 0; j < n_track; j++, i += 3) {
-					out[2] = c[i+2];
-					if (track_limit && (out[2] < t_low || out[2] > t_high)) continue;
-					out[0] = c[i] * R2D;
-					out[1] = c[i+1] * R2D;
+				if (n_m) {	/* Must generate intermediate points in time */
+					fprintf (stderr, "%s: Using drift file %s\n", GMT_program, drift_file);
+					t = (track_limit) ? t_low : 0.0;
+					t_end = (track_limit) ? t_high : age;
+					GMT_intpol (dt, dlon, n_m, 1, &t, &lon, gmtdefs.interpolant);
+					GMT_intpol (dt, dlat, n_m, 1, &t, &lat, gmtdefs.interpolant);
+					lon *= D2R;
+					lat *= D2R;
+					n_chunk = (*spot_func) (&lon, &lat, &t, 1, p, n_stages, 0.0, t_zero, TRUE + stage_id, NULL, &c);
+					out[0] = lon * R2D;
+					out[1] = lat * R2D;
+					out[2] = t;
 					GMT_output (fpo, n_out, out);
+					t += d_km;	/* dt, actually */
+					while (t < t_end) {
+						GMT_intpol (dt, dlon, n_m, 1, &t, &lon, gmtdefs.interpolant);
+						GMT_intpol (dt, dlat, n_m, 1, &t, &lat, gmtdefs.interpolant);
+						lon *= D2R;
+						lat *= D2R;
+						n_chunk = (*spot_func) (&lon, &lat, &t, 1, p, n_stages, 0.0, t_zero, TRUE + stage_id, NULL, &c);
+						lat = GMT_lat_swap (lat, GMT_LATSWAP_O2G);	/* Convert back to geodetic */
+						out[0] = lon * R2D;
+						out[1] = lat * R2D;
+						out[2] = t;
+						GMT_output (fpo, n_out, out);
+						t += d_km;	/* dt, actually */
+					}
+					GMT_intpol (dt, dlon, n_m, 1, &t_end, &lon, gmtdefs.interpolant);
+					GMT_intpol (dt, dlat, n_m, 1, &t_end, &lat, gmtdefs.interpolant);
+					lon *= D2R;
+					lat *= D2R;
+					n_chunk = (*spot_func) (&lon, &lat, &t_end, 1, p, n_stages, 0.0, t_zero, TRUE + stage_id, NULL, &c);
+					out[0] = lon * R2D;
+					out[1] = lat * R2D;
+					out[2] = t_end;
+					GMT_output (fpo, n_out, out);
+				}
+				else {
+					if (!confidence) n_chunk = (*spot_func) (&lon, &lat, &age, 1, p, n_stages, d_km, t_zero, TRUE + stage_id, NULL, &c);
+
+					i = 0;
+					n_track = irint (c[i++]);
+					for (j = 0; j < n_track; j++, i += 3) {
+						out[2] = c[i+2];
+						if (track_limit && (out[2] < t_low || out[2] > t_high)) continue;
+						out[0] = c[i] * R2D;
+						out[1] = c[i+1] * R2D;
+						out[GMT_Y] = GMT_lat_swap (out[GMT_Y], GMT_LATSWAP_O2G);	/* Convert back to geodetic */
+						GMT_output (fpo, n_out, out);
+					}
 				}
 				if (seg_files) GMT_fclose (fpo);
 
@@ -462,10 +551,12 @@ int main (int argc, char **argv)
 					}
 				}
 				else {
+					n_chunk = (*spot_func) (&lon, &lat, &age, 1, p, n_stages, 0.0, t_zero, TRUE + stage_id, NULL, &c);
 					out[0] = lon * R2D;
 					out[1] = lat * R2D;
 					for (k = 2; k < n_expected_fields; k++) out[k] = in[k];
 				}
+				out[GMT_Y] = GMT_lat_swap (out[GMT_Y], GMT_LATSWAP_O2G);	/* Convert back to geodetic */
 				GMT_output (fpo, n_out, out);
 			}
 
@@ -487,6 +578,11 @@ int main (int argc, char **argv)
 	/* Clean up and exit */
 
 	if (!single_rotation) GMT_free ((void *)p);
+	if (n_m) {
+		GMT_free ((void *)dlon);
+		GMT_free ((void *)dlat);
+		GMT_free ((void *)dt);
+	}
 	if (out) GMT_free ((void *)out);
 	
 	GMT_end (argc, argv);
