@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdrotater.c,v 1.34 2009/06/12 02:04:46 remko Exp $
+ *	$Id: grdrotater.c,v 1.38 2010/07/16 23:54:11 guru Exp $
  *
- *   Copyright (c) 1999-2009 by P. Wessel
+ *   Copyright (c) 1999-2010 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -32,15 +32,15 @@ int main (int argc, char **argv)
 	GMT_LONG i, j, k, ij, ii, jj, nx, ny, mx = 0, my, nm, ix, iy;
 	GMT_LONG iii, jjj, ii_o, jj_o;
 
-	BOOLEAN error = FALSE, interpolant = BCR_BICUBIC, user_polygon_given = FALSE;
-	BOOLEAN inside, node = FALSE, outline = TRUE, skip_grid = FALSE;
+	GMT_LONG error = FALSE, interpolant = BCR_BICUBIC, user_polygon_given = FALSE;
+	GMT_LONG inside, node = FALSE, outline = TRUE, skip_grid = FALSE;
 	
 	float *original_grid = VNULL, *rotated_grid;
 	char txt_a[GMT_TEXT_LEN], txt_b[GMT_TEXT_LEN], txt_c[GMT_TEXT_LEN];
 
 	double  xx, yy, lon, x_rot, y_rot, w_rot = 0.0, P_original[3], P_rotated[3], R[3][3];
 	double west, east, south, north, data_west, data_east, data_south, data_north;
-	double w180, w360, e180, e360, threshold = 1.0, out[2], *grd_x, *grd_y;
+	double w180, w360, e180, e360, threshold = 1.0, out[2], *grd_x, *grd_y, *grd_yc;
 	double wp180, wp360, ep180, ep360, spol, npol;
 
 	char *grdfile, *outfile, *pol_file;
@@ -52,7 +52,7 @@ int main (int argc, char **argv)
 
 	void get_grid_path (struct GRD_HEADER *h, struct GMT_TABLE **p);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
 	grdfile = outfile = pol_file = CNULL;
 	west = east = south = north = 0.0;
@@ -195,6 +195,8 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
+	GMT_lat_swap_init ();	/* Initialize auxiliary latitude machinery */
+
 	/* Check limits and get data file */
 
 	if (grdfile) {
@@ -267,9 +269,11 @@ int main (int argc, char **argv)
 		if (outline) GMT_write_segmentheader (GMT_stdout, 2);
 		wp360 = wp180 = DBL_MAX;	ep360 = ep180 = -DBL_MAX;	spol = DBL_MAX;	npol = -DBL_MAX;
 		for (j = 0; j < pol->segment[i]->n_rows; j++) {
+			pol->segment[i]->coord[GMT_Y][j] = GMT_lat_swap (pol->segment[i]->coord[GMT_Y][j], GMT_LATSWAP_G2O);	/* Convert to geocentric */
 			GMT_geo_to_cart (pol->segment[i]->coord[GMT_Y][j], pol->segment[i]->coord[GMT_X][j], P_original, TRUE);	/* Convert to a Cartesian x,y,z vector; TRUE since we have degrees */
 			spotter_matrix_vect_mult (R, P_original, P_rotated);				/* Rotate the vector */
 			GMT_cart_to_geo (&pol->segment[i]->coord[GMT_Y][j], &pol->segment[i]->coord[GMT_X][j], P_rotated, TRUE);	/* Recover lon lat representation; TRUE to get degrees */
+			pol->segment[i]->coord[GMT_Y][j] = GMT_lat_swap (pol->segment[i]->coord[GMT_Y][j], GMT_LATSWAP_O2G);	/* Convert back to geodetic */
 			if (pol->segment[i]->coord[GMT_Y][j] < south) south = pol->segment[i]->coord[GMT_Y][j];
 			if (pol->segment[i]->coord[GMT_Y][j] > north) north = pol->segment[i]->coord[GMT_Y][j];
 			if (pol->segment[i]->coord[GMT_Y][j] < spol) spol = pol->segment[i]->coord[GMT_Y][j];
@@ -342,10 +346,12 @@ int main (int argc, char **argv)
 	rotated_grid = (float *) GMT_memory (VNULL, (size_t)(r_head.nx * r_head.ny), sizeof (float), GMT_program);
 	grd_x = (double *) GMT_memory (VNULL, (size_t)r_head.nx, sizeof (double), GMT_program);
 	grd_y = (double *) GMT_memory (VNULL, (size_t)r_head.ny, sizeof (double), GMT_program);
+	grd_yc = (double *) GMT_memory (VNULL, (size_t)r_head.ny, sizeof (double), GMT_program);
 	r_head.xy_off = g_head.xy_off;
 	/* Precalculate node coordinates in both degrees and radians */
 	for (i = 0; i < r_head.nx; i++) grd_x[i] = GMT_i_to_x (i, r_head.x_min, r_head.x_max, r_head.x_inc, r_head.xy_off, r_head.nx);
 	for (j = 0; j < r_head.ny; j++) grd_y[j] = GMT_j_to_y (j, r_head.y_min, r_head.y_max, r_head.y_inc, r_head.xy_off, r_head.ny);
+	for (j = 0; j < r_head.ny; j++) grd_yc[j] = GMT_lat_swap (grd_y[j], GMT_LATSWAP_G2O);
 
 	/* Loop over all nodes in the new rotated grid and find those inside the reconstructed polygon */
 	
@@ -365,9 +371,10 @@ int main (int argc, char **argv)
 			
 			/* Here we are inside; get the coordinates and rotate back to original grid coordinates */
 			
-			GMT_geo_to_cart (grd_y[j], grd_x[j], P_rotated, TRUE);	/* Convert degree lon,lat to a Cartesian x,y,z vector */
+			GMT_geo_to_cart (grd_yc[j], grd_x[i], P_rotated, TRUE);	/* Convert degree lon,lat to a Cartesian x,y,z vector */
 			spotter_matrix_vect_mult (R, P_rotated, P_original);	/* Rotate the vector */
-			GMT_cart_to_geo (&yy, &xx, P_original, TRUE);	/* Recover degree lon lat representation */
+			GMT_cart_to_geo (&yy, &xx, P_original, TRUE);		/* Recover degree lon lat representation */
+			yy = GMT_lat_swap (yy, GMT_LATSWAP_O2G);		/* Convert back to geodetic */
 			xx -= 360.0;
 			while (xx < g_head.x_min) xx += 360.0;	/* Make sure we deal with 360 issues */
 			if (node) {
@@ -395,9 +402,10 @@ int main (int argc, char **argv)
 					if (iii < 0 || iii >= r_head.nx) continue;
 					ij = jjj * r_head.nx + iii;
 					if (!GMT_is_fnan (rotated_grid[ij])) continue;	/* Already done this */
-					GMT_geo_to_cart (grd_y[jjj], grd_x[iii], P_rotated, TRUE);	/* Convert degree lon,lat to a Cartesian x,y,z vector */
+					GMT_geo_to_cart (grd_yc[jjj], grd_x[iii], P_rotated, TRUE);	/* Convert degree lon,lat to a Cartesian x,y,z vector */
 					spotter_matrix_vect_mult (R, P_rotated, P_original);	/* Rotate the vector */
-					GMT_cart_to_geo (&xx, &yy, P_original, TRUE);	/* Recover degree lon lat representation */
+					GMT_cart_to_geo (&xx, &yy, P_original, TRUE);		/* Recover degree lon lat representation */
+					yy = GMT_lat_swap (yy, GMT_LATSWAP_O2G);		/* Convert back to geodetic */
 					ii_o = GMT_x_to_i (xx, g_head.x_min, g_head.x_inc, g_head.xy_off, g_head.nx);
 					if (ii_o < 0 || ii_o >= g_head.nx) continue;
 					jj_o = GMT_y_to_j (yy, g_head.y_min, g_head.y_inc, g_head.xy_off, g_head.ny);
@@ -422,6 +430,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)rotated_grid);
 	GMT_free ((void *)grd_x);
 	GMT_free ((void *)grd_y);
+	GMT_free ((void *)grd_yc);
 	
 	GMT_free_table (pol);
 
