@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: hotspotter.c,v 1.43 2009/07/11 03:16:32 guru Exp $
+ *	$Id: hotspotter.c,v 1.48 2010/07/16 23:54:11 guru Exp $
  *
- *   Copyright (c) 1999-2009 by P. Wessel
+ *   Copyright (c) 1999-2010 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -114,27 +114,27 @@ int main (int argc, char **argv)
 	GMT_LONG n_stages;		/* Number of stage rotations (poles) */
 	GMT_LONG n_chunk;		/* Number of path values returned by libspotter functions */
 	GMT_LONG n_track;		/* Number of points along a single flowline */
-	GMT_LONG node_x_width;	/* Number of x-nodes covered by the seamount in question (y-dependent) */
-	GMT_LONG node_y_width;	/* Number of y-nodes covered by the seamount */
+	GMT_LONG node_x_width;		/* Number of x-nodes covered by the seamount in question (y-dependent) */
+	GMT_LONG node_y_width;		/* Number of y-nodes covered by the seamount */
 	GMT_LONG n_args;		/* Command line argument counter */
-	int n_files = 0;	/* Number of input files on the command line */
-	GMT_LONG node;		/* The current node index */
-	int one_or_zero;	/* Will be 1 or 0 depending on grid format (-F) */
-	int n_fields, n_expected_fields;
+	GMT_LONG n_files = 0;		/* Number of input files on the command line */
+	GMT_LONG node;			/* The current node index */
+	GMT_LONG one_or_zero;		/* Will be 1 or 0 depending on grid format (-F) */
+	GMT_LONG n_fields, n_expected_fields;
 	GMT_LONG n_read = 0;		/* Number of records read */
-
 	GMT_LONG n_nodes;		/* Number of nodes in the output CVA grid */
+	GMT_LONG node_offset = 0;
 
 	/* Misc. counters */
 
 	GMT_LONG i, j, kx, ky, m, ii, jj, i0, j0, k0, dummy[4], fno;
 
-	BOOLEAN	error = FALSE;		/* TRUE when arguments are wrong */
-	BOOLEAN nofile = TRUE;		/* TRUE when data are to be read from stdin */
-	BOOLEAN truncate_ages = FALSE;	/* Truncate all seamounts ages > upper_age */
-	BOOLEAN finite = FALSE;		/* TRUE if stage pole file contains finite rotation poles instead */
-	BOOLEAN normalize = FALSE;	/* TRUE if we want CVA in percents */
-	BOOLEAN done;
+	GMT_LONG	error = FALSE;		/* TRUE when arguments are wrong */
+	GMT_LONG nofile = TRUE;		/* TRUE when data are to be read from stdin */
+	GMT_LONG truncate_ages = FALSE;	/* Truncate all seamounts ages > upper_age */
+	GMT_LONG finite = FALSE;		/* TRUE if stage pole file contains finite rotation poles instead */
+	GMT_LONG normalize = FALSE;	/* TRUE if we want CVA in percents */
+	GMT_LONG done;
 
 	float *CVA;			/* The CVA surface we seek to calculate */
 
@@ -160,6 +160,7 @@ int main (int argc, char **argv)
 	double offset;			/* 0.0 or 0.5, depending onf -F */
 	double half_dx, half_dy;	/* Half grid sizes or 0.0, depending on -F */
 	double *in;			/* GMT read array */
+	double south_c, north_c, yg;	/* Same but geocentric */
 
 	char *CVA_file = CNULL;		/* Output name of CVA grid */
 	char *euler_file = CNULL;	/* Input name of file with stage (Euler) rotations */
@@ -271,7 +272,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	GMT_check_lattice (&CVA_map.x_inc, &CVA_map.y_inc, &CVA_map.node_offset, NULL);
+	GMT_check_lattice (&CVA_map.x_inc, &CVA_map.y_inc, &node_offset, NULL);
+	CVA_map.node_offset = node_offset;
 
 	if (!project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
@@ -299,6 +301,8 @@ int main (int argc, char **argv)
 
 	/* ------------------- END OF PROCESSING COMMAND LINE ARGUMENTS  --------------------------------------*/
 
+	GMT_lat_swap_init ();	/* Initialize auxiliary latitude machinery */
+
 	/* Load in the Euler stage poles */
 
 	n_stages = spotter_init (euler_file, &p, TRUE, finite, FALSE, &upper_age, gmtdefs.verbose);
@@ -331,6 +335,8 @@ int main (int argc, char **argv)
 	east   = CVA_map.x_max * D2R;
 	south  = CVA_map.y_min * D2R;
 	north  = CVA_map.y_max * D2R;
+	south_c  = GMT_lat_swap (CVA_map.y_min, GMT_LATSWAP_G2O) * D2R;	/* Convert to geocentric */ 
+	north_c  = GMT_lat_swap (CVA_map.y_max, GMT_LATSWAP_G2O) * D2R;	/* Convert to geocentric */ 
 	i_xinc_r = 1.0 / xinc_r;
 	i_yinc_r = 1.0 / yinc_r;
 
@@ -404,10 +410,12 @@ int main (int argc, char **argv)
 			if (GMT_io.status & GMT_IO_EOF) continue;
 
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
 				continue;
 			}
 
+			in[GMT_Y] = GMT_lat_swap (in[GMT_Y], GMT_LATSWAP_G2O);	/* Convert to geocentric */
+
 			/* STEP 1: Read information about a single seamount from input record */
 
 			x_smt = in[0] * D2R;	/* Seamount positions in RADIANS */
@@ -457,7 +465,7 @@ int main (int argc, char **argv)
 
 				/* First throw out points outside specified grid region */
 
-				if (c[ky] < south || c[ky] > north) continue;	/* Latitude outside region */
+				if (c[ky] < south_c || c[ky] > north_c) continue;	/* Latitude outside region */
 
 				if (c[kx] > east) c[kx] -= TWO_PI;
 				while (c[kx] < west) c[kx] += TWO_PI;
@@ -465,8 +473,9 @@ int main (int argc, char **argv)
 
 				/* OK, this point is within our region, get node index */
 
+				yg = GMT_lat_swap (c[ky], GMT_LATSWAP_O2G);	/* Convert back to geodetic */
 				i = (GMT_LONG) floor (((c[kx] - west)  * i_xinc_r) + offset);
-				j = (GMT_LONG) floor (((north - c[ky]) * i_yinc_r) + offset);
+				j = (GMT_LONG) floor (((north - yg) * i_yinc_r) + offset);
 				node = j * CVA_map.nx + i;
 
 				if (!processed_node[node]) {	/* Have not added to the CVA at this node yet */
