@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: libspotter.c,v 1.61 2010/03/22 18:55:47 guru Exp $
+ *	$Id: libspotter.c,v 1.65 2010/09/17 07:35:57 guru Exp $
  *
  *   Copyright (c) 1999-2010 by P. Wessel
  *
@@ -43,6 +43,10 @@
  * flowline = TRUE when calling spotter_init and then:
  *	1. Draw FROM a hotspot TO a seamount: Use spotter_backtrack
  *	2. Draw FROM a seamount TO a hotspot (and beyond): Use spotter_forthtrack
+ *
+ * All coordinates herein are assumed to be GEOCENTRIC.  The main programs are
+ * respondible for coverting to/from geodetic data coordinates.  Rotation pole
+ * latitudes are usually implied to be geocentric.
  */
 
 #include "spotter.h"
@@ -115,7 +119,7 @@ int spotter_init (char *file, struct EULER **p, int flowline, GMT_LONG finite_in
 
 
 		if (e[i].t_stop >= e[i].t_start) {
-			fprintf (stderr, "libspotter: ERROR: Stage rotation %ld has start time younger than stop time\n", i);
+			fprintf (stderr, "libspotter: ERROR: (%s) Stage rotation %ld has start time younger than stop time\n", file, i);
 			GMT_exit (EXIT_FAILURE);
 		}
 		e[i].duration = e[i].t_start - e[i].t_stop;
@@ -153,7 +157,7 @@ int spotter_init (char *file, struct EULER **p, int flowline, GMT_LONG finite_in
 	/* Extend oldest stage pole back to t_max Ma */
 
 	if ((*t_max) > 0.0 && e[0].t_start < (*t_max)) {
-		if (verbose) fprintf (stderr, "libspotter: Extending oldest stage pole back to %g Ma\n", (*t_max));
+		if (verbose) fprintf (stderr, "libspotter: (%s) Extending oldest stage pole back to %g Ma\n", file, (*t_max));
 
 		e[0].t_start = (*t_max);
 		e[0].duration = e[0].t_start - e[0].t_stop;
@@ -811,9 +815,9 @@ void spotter_add_rotations (struct EULER a[], GMT_LONG n_a, struct EULER b[], GM
 	t_min = MAX (a[n_a-1].t_stop, b[n_b-1].t_stop);
 	t[n_k++] = t_max;
 	i = j = 0;
-	while (i < n_a && a[i].t_stop > t[0]) i++;
+	while (i < n_a && a[i].t_stop >= t[0]) i++;
 	if (i == (n_a - 1)) a_ok = FALSE;
-	while (j < n_b && b[j].t_stop > t[0]) j++;
+	while (j < n_b && b[j].t_stop >= t[0]) j++;
 	if (j == (n_b - 1)) b_ok = FALSE;
 	while (a_ok || b_ok) {
 		if (a_ok && !b_ok) {		/* Only a left */
