@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: originator.c,v 1.51 2009/07/11 03:16:32 guru Exp $
+ *	$Id: originator.c,v 1.57 2010/07/16 23:54:11 guru Exp $
  *
- *   Copyright (c) 2000-2009 by P. Wessel
+ *   Copyright (c) 2000-2010 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -104,18 +104,18 @@ struct HOTSPOT_ORIGINATOR {
 
 int main (int argc, char **argv)
 {
-	int x, y, n_max_spots, fno, n_files = 0, n_args, n_input = 5;
-	int n_fields, n_expected_fields, n_best_hs = 1, tdz_output = 0, n_out = 0;
+	GMT_LONG x, y, n_max_spots, fno, n_files = 0, n_args, n_input = 5;
+	GMT_LONG n_fields, n_expected_fields, n_best_hs = 1, tdz_output = 0, n_out = 0;
 	GMT_LONG  i, j, k, n, kk, ns, nh, nc, np, n_read, n_skipped = 0;
 
-	BOOLEAN	error = FALSE, done, nofile = TRUE, truncate_ages = FALSE, first = TRUE, better, use_ID = FALSE;
-	BOOLEAN finite = FALSE, degree = FALSE;		/* fitite is TRUE if stage pole file contains finite rotation poles instead */
+	GMT_LONG	error = FALSE, done, nofile = TRUE, truncate_ages = FALSE, first = TRUE, better, use_ID = FALSE;
+	GMT_LONG finite = FALSE, degree = FALSE;		/* fitite is TRUE if stage pole file contains finite rotation poles instead */
 
 	double x_smt, y_smt, z_smt, r_smt, t_smt, *c, *in, d_km = 5.0, upper_age = 180.0, dist, out[5];
 	double max_dist = 1.0e100, hx_dist, hx_dist_km, dist_NA, dist_NX, del_dist, dt = 0.0, A[3], H[3], N[3], X[3];
-	double dlon, fix_r, fix_t;
+	double dlon, fix_r, fix_t, yg, yc;
 
-	char *hsfile = CNULL, *efile = CNULL, age[GMT_TEXT_LEN], *not_used = NULL;
+	char *hsfile = CNULL, *efile = CNULL, age[GMT_TEXT_LEN], buffer[BUFSIZ], *not_used = NULL;
 
 	FILE *fp;
 
@@ -125,7 +125,6 @@ int main (int argc, char **argv)
 
 	int comp_hs (const void *p1, const void *p2);
 
-
 	argc = GMT_begin (argc, argv);
 
 	GMT_io.in_col_type[0] = GMT_io.out_col_type[0] = GMT_IS_LON;
@@ -223,7 +222,7 @@ int main (int argc, char **argv)
 	}
         if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN] = n_input;
         if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < n_input) {
-                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least %d columns\n", GMT_program, n_input);
+                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least %ld columns\n", GMT_program, n_input);
 		error++;
 	}
 
@@ -280,6 +279,8 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
+	GMT_lat_swap_init ();	/* Initialize auxiliary latitude machinery */
+
 	nh = spotter_hotspot_init (hsfile, &orig_hotspot);
 	if (n_best_hs <= 0 || n_best_hs > nh) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S:  Give value between 1 and %ld\n", GMT_program, nh);
@@ -327,7 +328,7 @@ int main (int argc, char **argv)
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
 				not_used = GMT_fgets (GMT_io.segment_header, BUFSIZ, fp);
-				if (first && !GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", GMT_io.segment_header);
+				if (first && !GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) GMT_fputs (GMT_io.segment_header, GMT_stdout);
 				n_read++;
 			}
 			first = FALSE;
@@ -343,9 +344,10 @@ int main (int argc, char **argv)
 			if (GMT_io.status & GMT_IO_EOF) continue;
 
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+				fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
 				continue;
 			}
+			
 			if (n_input == 3) {	/* set constant r,t values */
 				in[3] = fix_r;
 				in[4] = fix_t;
@@ -369,8 +371,9 @@ int main (int argc, char **argv)
 				n_skipped++;
 				continue;
 			}
+						
 			x_smt = in[0] * D2R;
-			y_smt = in[1] * D2R;
+			y_smt = GMT_lat_swap (in[GMT_Y], GMT_LATSWAP_G2O) * D2R;	/* Convert to geocentric */
 			z_smt = in[2];
 			r_smt = in[3];
 
@@ -383,8 +386,9 @@ int main (int argc, char **argv)
 			memcpy ((void *)hot, (void *)hotspot, nh * sizeof (struct HOTSPOT_ORIGINATOR));
 
 			for (kk = 0, k = 1; kk < np; kk++, k += 3) {	/* For this seamounts track */
+				yg = GMT_lat_swap (R2D*c[k+1], GMT_LATSWAP_O2G);	/* Convert back to geodetic */
 				for (j = 0; j < nh; j++) {	/* For all hotspots */
-					dist = GMT_great_circle_dist (hot[j].h->lon, hot[j].h->lat, R2D * c[k], R2D * c[k+1]);
+					dist = GMT_great_circle_dist (hot[j].h->lon, hot[j].h->lat, R2D * c[k], yg);
 					if (!degree) dist *= KM_PR_DEG;
 					if (dist < hot[j].np_dist) {
 						hot[j].np_dist = dist;
@@ -394,7 +398,8 @@ int main (int argc, char **argv)
 			}
 			for (j = 0; j < nh; j++) {
 
-				GMT_geo_to_cart (hot[j].h->lat, hot[j].h->lon, H, TRUE);	/* 3-D Cartesian vector of this hotspot */
+				yc = GMT_lat_swap (hot[j].h->lat, GMT_LATSWAP_G2O);	/* Convert to geocentric */
+				GMT_geo_to_cart (yc, hot[j].h->lon, H, TRUE);	/* 3-D Cartesian vector of this hotspot */
 
 				/* Fine-tune the nearest point by considering intermediate points along greatcircle between knot points */
 
@@ -436,7 +441,7 @@ int main (int argc, char **argv)
 				}
 				else {	/* Just use node coordinates */
 					hot[j].np_lon  = c[k] * R2D;	/* Longitude of the flowline's closest approach to hotspot */
-					hot[j].np_lat  = c[k+1] * R2D;	/* Latitude  of the flowline's closest approach to hotspot */
+					hot[j].np_lat  = GMT_lat_swap (c[k+1] * R2D, GMT_LATSWAP_O2G);	/* Geodetic latitude  of the flowline's closest approach to hotspot */
 					hot[j].np_time = c[k+2];	/* Predicted time at the flowline's closest approach to hotspot */
 				}
 
@@ -484,12 +489,19 @@ int main (int argc, char **argv)
 						strcpy (age, "NaN");
 					else
 						sprintf (age, "%g", t_smt);
-					fprintf (GMT_stdout, "%g\t%g\t%g\t%g\t%s", in[x], in[y], z_smt, r_smt, age);
+					sprintf (buffer, "%g\t%g\t%g\t%g\t%s", in[x], in[y], z_smt, r_smt, age);
+					GMT_fputs (buffer, GMT_stdout);
 					if (use_ID)
-						for (j = 0; j < n_max_spots; j++) fprintf (GMT_stdout, "\t%d\t%d\t%g\t%g", hot[j].h->id, hot[j].stage, hot[j].np_time, hot[j].np_dist);
+						for (j = 0; j < n_max_spots; j++) {
+							sprintf (buffer, "\t%d\t%d\t%g\t%g", hot[j].h->id, hot[j].stage, hot[j].np_time, hot[j].np_dist);
+							GMT_fputs (buffer, GMT_stdout);
+						}
 					else
-						for (j = 0; j < n_max_spots; j++) fprintf (GMT_stdout, "\t%s\t%d\t%g\t%g", hot[j].h->abbrev, hot[j].stage, hot[j].np_time, hot[j].np_dist);
-					fprintf (GMT_stdout, "\n");
+						for (j = 0; j < n_max_spots; j++) {
+							sprintf (buffer, "\t%s\t%d\t%g\t%g", hot[j].h->abbrev, hot[j].stage, hot[j].np_time, hot[j].np_dist);
+							GMT_fputs (buffer, GMT_stdout);
+						}
+					GMT_fputs ("\n", GMT_stdout);
 				}
 			}
 
