@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_datalist.c,v 1.49 2009/09/13 00:52:03 guru Exp $
+ *	$Id: x2sys_datalist.c,v 1.57 2010/03/24 17:06:23 jluis Exp $
  *
- *      Copyright (c) 1999-2009 by P. Wessel
+ *      Copyright (c) 1999-2010 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -33,18 +33,18 @@ struct X2SYS_ADJUST {
 	double *d, *c;
 };
 
-BOOLEAN x2sys_load_adjustments (char *DIR, char *TAG, char *track, char *column, struct X2SYS_ADJUST **A);
+GMT_LONG x2sys_load_adjustments (char *DIR, char *TAG, char *track, char *column, struct X2SYS_ADJUST **A);
 
 int main (int argc, char **argv)
 {
 	char *sfile, *def = "x2sys", *fflags = CNULL, *TAG = CNULL, *correction_table = CNULL;
-	char **trk_name = NULL;
+	char **trk_name = NULL, buffer[BUFSIZ];
 
 	GMT_LONG i, j, k, bad, trk_no, n_tracks;
 	GMT_LONG n_data_col_out = 0;
 
-	BOOLEAN error = FALSE, suppress = FALSE, apply_corrections = FALSE, t_given, set_r = FALSE;
-	BOOLEAN adjust = FALSE, cmdline_files, special_formatting = FALSE, *adj_col = NULL;
+	GMT_LONG error = FALSE, suppress = FALSE, apply_corrections = FALSE, t_given, set_r = FALSE;
+	GMT_LONG adjust = FALSE, cmdline_files, special_formatting = FALSE, xy_check, *adj_col = NULL;
 
 	double **data, west, east, south, north, *out, correction = 0.0, aux_dvalue[N_GENERIC_AUX];
 	double ds = 0.0, cumulative_dist, dist_scale = 1.0, dt, vel_scale = 1.0, adj_amount;
@@ -147,10 +147,14 @@ int main (int argc, char **argv)
 	if (fflags) x2sys_err_fail (x2sys_pick_fields (fflags, s), "-F");
 
 	s->ascii_out = !GMT_io.binary[1];
+	xy_check = (s->use_column[s->x_col[GMT_IN]] && s->use_column[s->y_col[GMT_IN]]);	/* TRUE means we requested lon,lat so we can check these for inside/outside */
 
 	if (set_r) {
-		west = B.x_min;	east = B.x_max;
+		west = B.x_min;		east = B.x_max;
 		south = B.y_min;	north = B.y_max;
+		if (!xy_check) {
+			fprintf (stderr, "%s: Region specified but lon/lat (or x/y) columns not selected; -R ignored\n", GMT_program);
+		}
 	}
 	if (project_info.region_supplied) {
 		/* Supply dummy linear proj */
@@ -166,11 +170,11 @@ int main (int argc, char **argv)
 	out = (double *) GMT_memory (VNULL, (size_t)s->n_fields, sizeof (double), "x2sys_datalist");
 
 	for (i = 0; i < s->n_out_columns; i++) {	/* Set output formats */
-		if (i == s->t_col)
+		if (i == s->t_col[GMT_OUT])
 			GMT_io.out_col_type[i] = GMT_IS_ABSTIME;
-		else if (i == s->x_col)
+		else if (i == s->x_col[GMT_OUT])
 			GMT_io.out_col_type[i] = (!strcmp (s->info[s->out_order[i]].name, "lon")) ? GMT_IS_LON : GMT_IS_FLOAT;
-		else if (i == s->y_col)
+		else if (i == s->y_col[GMT_OUT])
 			GMT_io.out_col_type[i] = (!strcmp (s->info[s->out_order[i]].name, "lat")) ? GMT_IS_LAT : GMT_IS_FLOAT;
 		else
 			GMT_io.out_col_type[i] = GMT_IS_FLOAT;
@@ -181,9 +185,9 @@ int main (int argc, char **argv)
 
 	if (suppress) {	/* Must count output data columns (except t, x, y) */
 		for (i = n_data_col_out = 0; i < s->n_out_columns; i++) {
-			if (s->out_order[i] == s->t_col) continue;
-			if (s->out_order[i] == s->x_col) continue;
-			if (s->out_order[i] == s->y_col) continue;
+			if (i == s->t_col[GMT_OUT]) continue;
+			if (i == s->x_col[GMT_OUT]) continue;
+			if (i == s->y_col[GMT_OUT]) continue;
 			n_data_col_out++;
 		}
 	}
@@ -250,7 +254,7 @@ int main (int argc, char **argv)
 	
 	if (apply_corrections) {	/* Load an ephemeral correction table */
 		x2sys_get_corrtable (s, correction_table, n_tracks, trk_name, NULL, aux, auxlist, &CORR);
-		if (auxlist[MGD77_AUX_SP].requested && s->t_col == -1) {
+		if (auxlist[MGD77_AUX_SP].requested && s->t_col[GMT_IN] == -1) {
 			fprintf (stderr, "%s: Selected correction table requires velocity which implies time (not selected)\n", GMT_program);
 			MGD77_Free_Correction (CORR, n_tracks);
 			x2sys_free_list (trk_name, n_tracks);
@@ -260,7 +264,7 @@ int main (int argc, char **argv)
 
 	if (adjust) {
 		A = (struct X2SYS_ADJUST **) GMT_memory (VNULL, s->n_out_columns, sizeof (struct X2SYS_ADJUST *), GMT_program);
-		adj_col = (BOOLEAN *) GMT_memory (VNULL, s->n_out_columns, sizeof (BOOLEAN), GMT_program);
+		adj_col = (GMT_LONG *) GMT_memory (VNULL, s->n_out_columns, sizeof (GMT_LONG), GMT_program);
 	}
 	
 	for (trk_no = 0; trk_no < n_tracks; trk_no++) {
@@ -269,63 +273,65 @@ int main (int argc, char **argv)
 
 		x2sys_err_fail ((s->read_file) (trk_name[trk_no], &data, s, &p, &GMT_io, &k), trk_name[trk_no]);
 
-		if (apply_corrections && s->t_col >= 0) MGD77_Init_Correction (CORR[trk_no], data);	/* Initialize origins if needed */
+		if (apply_corrections && s->t_col[GMT_IN] >= 0) MGD77_Init_Correction (CORR[trk_no], data);	/* Initialize origins if needed */
 
 		if (adjust) {
-			for (k = 0; k < s->n_out_columns; k++) adj_col[k] = x2sys_load_adjustments (X2SYS_HOME, TAG, trk_name[trk_no], s->info[k].name, &A[k]);
+			for (k = 0; k < s->n_out_columns; k++) adj_col[k] = x2sys_load_adjustments (X2SYS_HOME, TAG, trk_name[trk_no], s->info[s->out_order[k]].name, &A[k]);
 		}
 
 		if (GMT_io.multi_segments[GMT_OUT]) GMT_write_segmentheader (GMT_stdout, s->n_fields);
 
 		cumulative_dist = 0.0;
 		for (j = 0; j < p.n_rows; j++) {
-			if (project_info.region_supplied && GMT_map_outside (data[s->x_col][j], data[s->y_col][j])) continue;
+			if (project_info.region_supplied && xy_check && GMT_map_outside (data[s->x_col[GMT_OUT]][j], data[s->y_col[GMT_OUT]][j])) continue;
 			if (suppress) {
-				for (i = bad = 0; i < s->n_out_columns; i++) {
-					if (s->out_order[i] == s->t_col) continue;
-					if (s->out_order[i] == s->x_col) continue;
-					if (s->out_order[i] == s->y_col) continue;
-					if (GMT_is_dnan (data[s->out_order[i]][j])) bad++;
+				for (k = bad = 0; k < s->n_out_columns; k++) {
+					if (k == s->t_col[GMT_OUT]) continue;
+					if (k == s->x_col[GMT_OUT]) continue;
+					if (k == s->y_col[GMT_OUT]) continue;
+					if (GMT_is_dnan (data[k][j])) bad++;
 				}
 				if (bad == n_data_col_out) continue;
 			}
 			if (auxlist[MGD77_AUX_AZ].requested) {
 				if (j == 0)	/* Look forward at first point to get an azimuth */
-					aux_dvalue[MGD77_AUX_AZ] = GMT_azimuth_func (data[s->x_col][1], data[s->y_col][1], data[s->x_col][0], data[s->y_col][0], FALSE);
+					aux_dvalue[MGD77_AUX_AZ] = GMT_azimuth_func (data[s->x_col[GMT_OUT]][1], data[s->y_col[GMT_OUT]][1], data[s->x_col[GMT_OUT]][0], data[s->y_col[GMT_OUT]][0], FALSE);
 				else		/* else go from previous to this point */
-					aux_dvalue[MGD77_AUX_AZ] = GMT_azimuth_func (data[s->x_col][j], data[s->y_col][j], data[s->x_col][j-1], data[s->y_col][j-1], FALSE);
+					aux_dvalue[MGD77_AUX_AZ] = GMT_azimuth_func (data[s->x_col[GMT_OUT]][j], data[s->y_col[GMT_OUT]][j], data[s->x_col[GMT_OUT]][j-1], data[s->y_col[GMT_OUT]][j-1], FALSE);
 			}
 			if (auxlist[MGD77_AUX_DS].requested) {
-				ds = (j == 0) ? 0.0 : dist_scale * GMT_distance_func (data[s->x_col][j], data[s->y_col][j], data[s->x_col][j-1], data[s->y_col][j-1]);
+				ds = (j == 0) ? 0.0 : dist_scale * GMT_distance_func (data[s->x_col[GMT_OUT]][j], data[s->y_col[GMT_OUT]][j], data[s->x_col[GMT_OUT]][j-1], data[s->y_col[GMT_OUT]][j-1]);
 				cumulative_dist += ds;
 				aux_dvalue[MGD77_AUX_DS] = cumulative_dist;
 			}
 			if (auxlist[MGD77_AUX_SP].requested) {
-				dt =  (j == 0) ? data[s->t_col][1] - data[s->t_col][0] : data[s->t_col][j] - data[s->t_col][j-1];
+				dt =  (j == 0) ? data[s->t_col[GMT_OUT]][1] - data[s->t_col[GMT_OUT]][0] : data[s->t_col[GMT_OUT]][j] - data[s->t_col[GMT_OUT]][j-1];
 				aux_dvalue[MGD77_AUX_SP] = (GMT_is_dnan (dt) || dt == 0.0) ? GMT_d_NaN : vel_scale * ds / dt;
 			}
 			for (k = 0; k < s->n_out_columns; k++) {	/* Load output record */
 				correction = (apply_corrections) ? MGD77_Correction (CORR[trk_no][k].term, data, aux_dvalue, j) : 0.0;
 				if (adjust && adj_col[k]) {
 					if (GMT_intpol (A[k]->d, A[k]->c, A[k]->n, 1, &aux_dvalue[MGD77_AUX_DS], &adj_amount, gmtdefs.interpolant)) {
-						fprintf (stderr, "%s: Error interpolating adjustment for %s near row %ld - no adjustment made!\n", GMT_program, s->info[k].name, j);
+						fprintf (stderr, "%s: Error interpolating adjustment for %s near row %ld - no adjustment made!\n", GMT_program, s->info[s->out_order[k]].name, j);
 						adj_amount = 0.0;
 					}
 					correction -= adj_amount;
 				}
-				out[k] = data[k][j] - correction;
+				out[k] = data[k][j] - correction;	/* This loads out in the correct output order */
 			}
 			if (special_formatting)  {	/* use the specified formats */
 				for (k = 0; k < s->n_out_columns; k++) {
 					if (s->info[s->out_order[k]].format[0] == '-')
 						GMT_ascii_output_one (GMT_stdout, out[k], k);
 					else {
-						if (!GMT_is_dnan (out[k]))
-							fprintf (GMT_stdout, s->info[s->out_order[k]].format, out[k]);
+						if (!GMT_is_dnan (out[k])) {
+							sprintf (buffer, s->info[s->out_order[k]].format, out[k]);
+							GMT_fputs (buffer, GMT_stdout);
+						}
 						else
-							fprintf (GMT_stdout, "NaN");
+							GMT_fputs ("NaN", GMT_stdout);
 					}
-					(k == (s->n_out_columns - 1)) ? fprintf (GMT_stdout, "\n") : fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+					(k == (s->n_out_columns - 1)) ? GMT_fputs ("\n", GMT_stdout) : GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 				}
 			}
 			else {
@@ -334,7 +340,7 @@ int main (int argc, char **argv)
 		}
 
 		x2sys_free_data (data, s->n_out_columns, &p);
-		for (k = 0; k < s->n_out_columns; k++) if (adjust && adj_col[k]) {
+		for (k = 0; k < s->n_fields; k++) if (adjust && adj_col[k]) {
 			GMT_free ((void *)A[k]->d);
 			GMT_free ((void *)A[k]->c);
 			GMT_free ((void *)A[k]);
@@ -356,7 +362,7 @@ int main (int argc, char **argv)
 	exit (EXIT_SUCCESS);
 }
 
-BOOLEAN x2sys_load_adjustments (char *DIR, char *TAG, char *track, char *column, struct X2SYS_ADJUST **A)
+GMT_LONG x2sys_load_adjustments (char *DIR, char *TAG, char *track, char *column, struct X2SYS_ADJUST **A)
 {
 	GMT_LONG n_fields, n_expected_fields = 2, n = 0, k, type[2] = {GMT_IS_FLOAT, GMT_IS_FLOAT}, n_alloc = GMT_CHUNK;
 	double *in;
