@@ -1,8 +1,8 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_get.c,v 1.45 2009/06/25 03:25:07 guru Exp $
+ *	$Id: x2sys_get.c,v 1.55 2010/03/24 16:43:44 jluis Exp $
  *
- *      Copyright (c) 1999-2009 by P. Wessel
- *      See COPYING file for copying and redistribution conditions.
+ *      Copyright (c) 1999-2010 by P. Wessel
+ *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -29,31 +29,38 @@
 
 #include "x2sys.h"
 
+int find_leg (char *name, struct X2SYS_BIX *B, int n)
+{	/* Return track id # for this leg */
+	int i;
+
+	for (i = 0; i < n; i++) if (!strcmp (name, B->head[i].trackname)) return (i);
+	return (-1);
+}
+
 int main (int argc, char **argv)
 {
-	char *TAG = CNULL, *fflags = CNULL, *nflags = CNULL, *fx = NULL;
-	char *y_match = NULL, *n_match = NULL, line[BUFSIZ];
+	char *TAG = NULL, *fflags = NULL, *nflags = NULL, *fx = NULL;
+	char *y_match = NULL, *n_match = NULL, line[BUFSIZ], *p = NULL;
 	
 	double x, y;
 
-	struct X2SYS_INFO *s;
+	struct X2SYS_INFO *s = NULL;
 	struct X2SYS_BIX B;
-	struct X2SYS_BIX_TRACK *track;
+	struct X2SYS_BIX_TRACK *track = NULL;
 
-	BOOLEAN error = FALSE, no_suffix = FALSE, center = FALSE, x_setup = FALSE;
-	BOOLEAN y_ok, n_ok, first, *include = NULL, swap = FALSE;
+	GMT_LONG error = FALSE, no_suffix, center = FALSE, x_setup = FALSE;
+	GMT_LONG y_ok, n_ok, first, *include = NULL, swap = FALSE, quick = FALSE;
+	GMT_LONG internal = TRUE, external = TRUE, extension = FALSE, dump = FALSE;
 
 	int combo = 0, ij, n_tracks_found, n_tracks, bit;
 	int id1, id2, item, n_flags = 0, n_pairs, missing = 0, *ids_in_bin = NULL;
-	GMT_LONG i, j, k, kk, start_j, start_i, stop_j, stop_i;
+	GMT_LONG i, j, k, kk, c, start_j, start_i, stop_j, stop_i;
 	
 	unsigned int *matrix = NULL;
 
 	double west = 0.0, east = 0.0, south = 0.0, north = 0.0;
 	
-	FILE *fp;
-
-	int find_leg (char *name, struct X2SYS_BIX *B, int n);
+	FILE *fp = NULL, *fpd = NULL;
 
 	argc = GMT_begin (argc, argv);
 	
@@ -71,14 +78,15 @@ int main (int argc, char **argv)
 				case 'C':
 					center = TRUE;
 					break;
+				case 'D':
+					quick = TRUE;	/* Just list track names and not the full report  */
+					break;
+				case 'E':
+					extension = TRUE;
+					break;
 				case 'F':
 					fflags = &argv[i][2];
 					break;
-#if 0
-				case 'S':
-					no_suffix = TRUE;
-					break;
-#endif
 				case 'L':
 					if (argv[i][2]) fx = &argv[i][2];
 					x_setup = TRUE;
@@ -89,9 +97,16 @@ int main (int argc, char **argv)
 				case 'T':
 					TAG = &argv[i][2];
 					break;
+				case 'Q':	/* Specify internal or external only */
+					if (argv[i][2] == 'e') internal = FALSE;
+					if (argv[i][2] == 'i') external = FALSE;
+					break;
 				case 's':
 					swap = TRUE;	/* Undocumented swap option for index.b reading */
 					break;
+				case 'd':
+					dump = TRUE;	/* Undocumented dump option for index.b debugging */
+					break;
 				default:
 					error = TRUE;
 					fprintf (stderr, "%s: Unrecognized option -%c\n", GMT_program, argv[i][1]);
@@ -102,22 +117,23 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || error || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "x2sys_get %s - Get track listing from track index database\n\n", X2SYS_VERSION);
-		fprintf (stderr, "usage: x2sys_get -T<TAG> [-C] [-F<fflags>] [-L[list]] [-N<nflags>] [%s] [-V]\n\n", GMT_Rgeo_OPT);
+		fprintf (stderr, "usage: x2sys_get -T<TAG> [-C] [-D] [-E] [-F<fflags>] [-L[list]] [-N<nflags>] [-Qe|i] [%s] [-V]\n\n", GMT_Rgeo_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		fprintf (stderr, "\n\tOPTIONS:\n");
-		fprintf (stderr, "	-C reports center of each tile with tracks instead [Default is track files]\n");
-		fprintf (stderr, "	-F is comma-separated list of column names that must be present [Default is any field]\n");
-		fprintf (stderr, "	-L Setup mode: Return all pairs of cruises that might intersect given\n");
+		fprintf (stderr, "	-C reports center of each tile with tracks instead [Default is track files].\n");
+		fprintf (stderr, "	-D only reports the track names and not the report on each field.\n");
+		fprintf (stderr, "	-E Append the filename extensions in the report [just track name].\n");
+		fprintf (stderr, "	-F is comma-separated list of column names that must be present [Default is any field].\n");
+		fprintf (stderr, "	-L Setup mode: Return all pairs of cruises that might intersect given.\n");
 		fprintf (stderr, "	   the bin distribution.  Optionally, give file with a list of cruises.\n");
 		fprintf (stderr, "	   Then, only pairs with at least one cruise from the list is output.\n");
-		fprintf (stderr, "	-N is comma-separated list of column names that must be missing\n");
+		fprintf (stderr, "	-N is comma-separated list of column names that must be missing.\n");
+		fprintf (stderr,"	-Q Append e for external or i for internal crossovers [Default is both].\n");
+		fprintf (stderr,"	   Requires -L and affects the pairs that are returned.\n");
 		GMT_explain_option ('R');
 		fprintf (stderr, "	[Default region is the entire data domain]\n");
-#if 0
-		fprintf (stderr, "	-S reports tracks files without suffix [Default is file name]\n");
-#endif
 		GMT_explain_option ('V');
 		exit (EXIT_FAILURE);
 	}
@@ -155,9 +171,11 @@ int main (int argc, char **argv)
 
 	x2sys_err_fail (x2sys_bix_read_index (s, &B, swap), "");
 
+	no_suffix = !extension;
+	
 	if (x_setup) {
 		n_flags = (int)ceil (n_tracks / 32.0);
-		include = (BOOLEAN *) GMT_memory (VNULL, (size_t)n_tracks, sizeof (BOOLEAN), GMT_program);
+		include = (GMT_LONG *) GMT_memory (VNULL, (size_t)n_tracks, sizeof (GMT_LONG), GMT_program);
 		if (fx) {
 			if ((fp = fopen (fx, "r")) == NULL) {
 				fprintf (stderr, "%s: ERROR: -L unable to open file %s\n", GMT_program, fx);
@@ -166,6 +184,7 @@ int main (int argc, char **argv)
 			while (fgets (line, BUFSIZ, fp)) {
 				GMT_chop (line);	/* Get rid of [CR]LF */
 				if (line[0] == '#' || line[0] == '\0') continue;
+				if ((p = strchr (line, '.'))) line[(int)(p-line)] = '\0';	/* Remove extension */
 				k = find_leg (line, &B, n_tracks);	/* Return track id # for this leg */
 				if (k == -1) {
 					fprintf (stderr, "%s: Warning: Leg %s not in the data base\n", GMT_program, line);
@@ -192,12 +211,29 @@ int main (int argc, char **argv)
 	x2sys_err_fail (x2sys_bix_get_ij (east, north, &stop_i, &stop_j, &B, &j), "");
 	if (B.periodic && stop_i < start_i) stop_i += B.nx_bin;	/* Deal with longitude periodicity */
 
+	if (dump) {
+		fpd = fopen ("x2sys_index_dump.txt", "w");
+		fprintf (fpd, "# Complete dump of x2sys_index.b for this region and tag.\n");
+		fprintf (fpd, "# Segment header shows index number, the center location, and number of tracks crossing this bin.\n");
+		fprintf (fpd, "# Each track entry shows track name, integer flag, and Y|N for all observables.  The columns are:\n# Track\t\tflag");
+		for (c = 0; c < s->n_fields; c++) fprintf (fpd, "\t%s", s->info[c].name);
+		fprintf (fpd, "\n#\n");
+	}
 	for (j = start_j; j <= stop_j; j++) {
 		for (i = start_i; i <= stop_i; i++) {
 			ij = j * B.nx_bin + (i % B.nx_bin);	/* Since i may exceed nx_bin due to longitude periodicity */
+			if (dump) fprintf (fpd, "> Index %d lon = %g lat = %g n_tracks = %d\n", ij, B.x_min + ((ij % B.nx_bin) + 0.5) * B.bin_x, B.y_min + ((ij / B.nx_bin) + 0.5) * B.bin_y, B.base[ij].n_tracks);
 			if (B.base[ij].n_tracks == 0) continue;
 
 			for (k = kk = 0, track = B.base[ij].first_track->next_track, first = TRUE; first && k < B.base[ij].n_tracks; k++, track = track->next_track) {
+				if (dump) {	/* Write out all info for each track in this bin */
+					fprintf (fpd, "%s\t%d", B.head[track->track_id].trackname, track->track_flag);
+					for (c = 0, bit = 1; c < s->n_fields; c++, bit <<= 1) {
+						(track->track_flag & bit) ? fprintf (fpd, "\tY") : fprintf (fpd, "\tN");
+					}
+					fprintf (fpd, "\n");
+				}
+					
 				if (x_setup) {	/* Just build integer list of track ids for this bin */
 					y_ok = n_ok = TRUE;
 					if (fflags) y_ok = ((track->track_flag & combo) == combo);	/* Each cruise must have the requested fields */
@@ -215,9 +251,9 @@ int main (int argc, char **argv)
 						x = B.x_min + ((ij % B.nx_bin) + 0.5) * B.bin_x;
 						y = B.y_min + ((ij / B.nx_bin) + 0.5) * B.bin_y;
 						GMT_ascii_output_one (GMT_stdout, x, 0);
-						fprintf (GMT_stdout, "%s", gmtdefs.field_delimiter);
+						GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 						GMT_ascii_output_one (GMT_stdout, y, 1);
-						fprintf (GMT_stdout, "\n");
+						GMT_fputs ("\n", GMT_stdout);
 						first = FALSE;
 					}
 				}
@@ -238,9 +274,14 @@ int main (int argc, char **argv)
 				
 		}
 	}
-
+	if (dump) {
+		fclose (fpd);
+		fprintf (stderr, "%s: Index debug dump for selected region written to x2sys_index_dump.txt\n", GMT_program);
+	}
 	if (x_setup) {
 		for (id1 = n_pairs = 0; id1 < n_tracks; id1++) {
+			if (internal && include[id1]) printf ("%s\t%s\n", B.head[id1].trackname, B.head[id1].trackname);
+			if (!external) continue;	/* Skip all external comparisons */
 			for (id2 = id1 + 1; id2 < n_tracks; id2++) {
 				item = id2 / 32;
 				bit = id2 % 32;
@@ -263,11 +304,13 @@ int main (int argc, char **argv)
 		if (n_tracks_found) {
 			if (gmtdefs.verbose ) fprintf (stderr, "%s: Found %d tracks\n", GMT_program, n_tracks_found);
 	
-			printf ("# Search command: %s", GMT_program);
-			for (i = 1; i < argc; i++) printf (" %s", argv[i]);
-			printf ("\n#track_ID\t");
-			for (i = 0; i < (s->n_fields-1); i++) printf ("%s\t", s->info[i].name);
-			printf ("%s\n", s->info[s->n_fields-1].name);
+			if (!quick) {
+				printf ("# Search command: %s", GMT_program);
+				for (i = 1; i < argc; i++) printf (" %s", argv[i]);
+				printf ("\n#track_ID\t");
+				for (c = 0; c < (s->n_fields-1); c++) printf ("%s\t", s->info[c].name);
+				printf ("%s\n", s->info[s->n_fields-1].name);
+			}
 			for (k = 0; k < n_tracks; k++) {
 				if (y_match[k] == 0 || n_match[k] == 1) continue;
 				if (no_suffix) {
@@ -275,8 +318,11 @@ int main (int argc, char **argv)
 					if (i) B.head[k].trackname[i] = '\0';
 				}
 				printf ("%s", B.head[k].trackname);
-				for (i = 0, bit = 1; i < s->n_fields; i++, bit <<= 1) {
-					(B.head[k].flag & bit) ? printf ("\tY") : printf ("\tN");
+				if (extension) printf (".%s", s->suffix);
+				if (!quick) {
+					for (c = 0, bit = 1; c < s->n_fields; c++, bit <<= 1) {
+						(B.head[k].flag & bit) ? printf ("\tY") : printf ("\tN");
+					}
 				}
 				printf ("\n");
 			}
@@ -295,12 +341,3 @@ int main (int argc, char **argv)
 
 	exit (EXIT_SUCCESS);
 }
-
-int find_leg (char *name, struct X2SYS_BIX *B, int n)
-{	/* Return track id # for this leg */
-	int i;
-	
-	for (i = 0; i < n; i++) if (!strcmp (name, B->head[i].trackname)) return (i);
-	return (-1);
-}
-
